@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: GameJoystick.cpp,v 1.11 2009/06/03 17:48:27 bowkenken Exp $
+* $Id: GameJoystick.cpp,v 1.12 2009/06/28 09:37:46 bowkenken Exp $
 ***************************************************************/
 
 ////////////////////////////////////////////////////////////////
@@ -599,13 +599,13 @@ void GameJoystick::joyMoveRepeat()
 
 	if( flagMenu ){
 		for( long i = 0; i < x; i++ )
-			gKey.setChar( '6', true );
+			gKey.setChar( '6', false, true );
 		for( long i = 0; i < -x; i++ )
-			gKey.setChar( '4', true );
+			gKey.setChar( '4', false, true );
 		for( long i = 0; i < y; i++ )
-			gKey.setChar( '2', true );
+			gKey.setChar( '2', false, true );
 		for( long i = 0; i < -y; i++ )
-			gKey.setChar( '8', true );
+			gKey.setChar( '8', false, true );
 	} else {
 		if( (x == 0) && (y == 0) )
 			return;
