@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: GuiChrSheet.cpp,v 1.25 2009/06/03 18:09:10 bowkenken Exp $
+* $Id: GuiChrSheet.cpp,v 1.26 2009/07/02 01:44:52 bowkenken Exp $
 ***************************************************************/
 
 ////////////////////////////////////////////////////////////////
@@ -3451,7 +3451,12 @@ bool GuiChrSheet::raceClicked()
 	DdxFromSheet();
 
 	set_data_n( DATA_N_RACE_STR );
-	gKey.setChar( '\n' );
+
+	if( get_flg_space_select() )
+		gKey.setChar( ' ' );
+	else
+		gKey.setChar( '\n' );
+
 	return true;
 }
 
@@ -3495,7 +3500,12 @@ bool GuiChrSheet::sexClicked()
 	DdxFromSheet();
 
 	set_data_n( DATA_N_SEX );
-	gKey.setChar( '\n' );
+
+	if( get_flg_space_select() )
+		gKey.setChar( ' ' );
+	else
+		gKey.setChar( '\n' );
+
 	return true;
 }
 
@@ -3511,7 +3521,12 @@ bool GuiChrSheet::tileClicked()
 	DdxFromSheet();
 
 	set_data_n( DATA_N_GRAPH_FILE );
-	gKey.setChar( '\n' );
+
+	if( get_flg_space_select() )
+		gKey.setChar( ' ' );
+	else
+		gKey.setChar( '\n' );
+
 	return true;
 }
 
@@ -3528,7 +3543,12 @@ bool GuiChrSheet::classClicked()
 	DdxFromSheet();
 
 	set_data_n( DATA_N_CLASS );
-	gKey.setChar( '\n' );
+
+	if( get_flg_space_select() )
+		gKey.setChar( ' ' );
+	else
+		gKey.setChar( '\n' );
+
 	return true;
 }
 
@@ -3547,7 +3567,12 @@ bool GuiChrSheet::skillClicked( long n )
 	DdxFromSheet();
 
 	set_data_n( data );
-	gKey.setChar( '\n' );
+
+	if( get_flg_space_select() )
+		gKey.setChar( ' ' );
+	else
+		gKey.setChar( '\n' );
+
 	return true;
 }
 
@@ -3566,7 +3591,12 @@ bool GuiChrSheet::itemClicked( long n )
 	DdxFromSheet();
 
 	set_data_n( data );
-	gKey.setChar( '\n' );
+
+	if( get_flg_space_select() )
+		gKey.setChar( ' ' );
+	else
+		gKey.setChar( '\n' );
+
 	return true;
 }
 
@@ -3585,7 +3615,12 @@ bool GuiChrSheet::equipClicked( long n )
 	DdxFromSheet();
 
 	set_data_n( data );
-	gKey.setChar( '\n' );
+
+	if( get_flg_space_select() )
+		gKey.setChar( ' ' );
+	else
+		gKey.setChar( '\n' );
+
 	return true;
 }
 
