@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2008 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: GuiInputString.cpp,v 1.20 2008/08/18 08:25:38 bowkenken Exp $
+* $Id: GuiInputString.cpp,v 1.23 2009/03/04 11:47:40 bowkenken Exp $
 ***************************************************************/
 
 ////////////////////////////////////////////////////////////////
@@ -43,13 +43,13 @@
 gint handle_input_string_delete(
 	GtkWidget *widget, gpointer user_data
 );
-void handle_input_string_destroy(
+gint handle_input_string_destroy(
 	GtkWidget *widget, gpointer user_data
 );
-void handle_input_string_cancel_clicked(
+gint handle_input_string_cancel_clicked(
 	GtkWidget *widget, gpointer user_data
 );
-void handle_input_string_ok_clicked(
+gint handle_input_string_ok_clicked(
 	GtkWidget *widget, gpointer user_data
 );
 #endif // D_GTK
@@ -288,8 +288,8 @@ void GuiInputString::draw( const char *ttl, const char *str, long len )
 	INT_PTR res = mInpStrWin->DoModal();
 
 	if( res == IDOK )
-		set_key_buf_str( mInpStrWin->m_EditDdx );
-	set_key_buf_str( "\n" );
+		set_key_buf_str_tail( mInpStrWin->m_EditDdx );
+	set_key_buf_str_tail( "\n" );
 #endif // D_MFC
 }
 
@@ -313,10 +313,10 @@ gint handle_input_string_delete(
 	GtkWidget *widget, gpointer user_data
 )
 {
-	set_key_buf_str( "\n" );
+	set_key_buf_str_tail( "\n" );
 	gGuiInpStr.wipe();
 
-	return true;
+	return 0;
 }
 #endif // D_GTK
 
@@ -325,11 +325,13 @@ gint handle_input_string_delete(
 ////////////////////////////////////////////////////////////////
 
 #ifdef D_GTK
-void handle_input_string_destroy(
+gint handle_input_string_destroy(
 	GtkWidget *widget, gpointer user_data
 )
 {
 	gGuiInpStr.wipe();
+
+	return 0;
 }
 #endif // D_GTK
 
@@ -338,12 +340,14 @@ void handle_input_string_destroy(
 ////////////////////////////////////////////////////////////////
 
 #ifdef D_GTK
-void handle_input_string_cancel_clicked(
+gint handle_input_string_cancel_clicked(
 	GtkWidget *widget, gpointer user_data
 )
 {
-	set_key_buf_str( "\n" );
+	set_key_buf_str_tail( "\n" );
 	gGuiInpStr.wipe();
+
+	return 0;
 }
 #endif // D_GTK
 
@@ -352,32 +356,22 @@ void handle_input_string_cancel_clicked(
 ////////////////////////////////////////////////////////////////
 
 #ifdef D_GTK
-void handle_input_string_ok_clicked(
+gint handle_input_string_ok_clicked(
 	GtkWidget *widget, gpointer user_data
 )
 {
-#ifdef D_WS
-	WSCvifield *w = InpStrField;
-
-	if( w != NULL ){
-		WSCstring s = ((char *)w->getProperty( WSNlabelString ));
-
-		set_key_buf_str( s );
-	}
-#endif // D_WS
-
-#ifdef D_GTK
 	GtkEntry *w = GTK_ENTRY( gGuiInpStr.mEntry );
 
 	if( w != NULL ){
 		const gchar *buf = gtk_entry_get_text( w );
 		WSCstring s = (char *)buf;
 
-		set_key_buf_str( s );
+		set_key_buf_str_tail( s );
 	}
-#endif	// D_GTK
 
-	set_key_buf_str( "\n" );
+	set_key_buf_str_tail( "\n" );
 	gGuiInpStr.wipe();
+
+	return 0;
 }
 #endif // D_GTK
