@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: GuiMenu.cpp,v 1.40 2009/06/21 13:47:44 bowkenken Exp $
+* $Id: GuiMenu.cpp,v 1.44 2009/07/12 11:38:28 bowkenken Exp $
 ***************************************************************/
 
 ////////////////////////////////////////////////////////////////
@@ -61,6 +61,10 @@ void EpGuiMenuSel( WSCbase *obj );
 
 #ifdef D_GTK
 
+gint handle_menu_win_delete(
+	GtkWidget *widget, gpointer data
+);
+
 gint handle_menu_win_destroy(
 	GtkWidget *widget, gpointer data
 );
@@ -100,7 +104,6 @@ gint handle_menu_button_leave(
 GuiMenu::GuiMenu()
 {
 	mMenuWin = NULL;
-	bFlagSetMouseDfltMenu = false;
 
 #ifdef D_GTK
 	vBox = NULL;
@@ -199,10 +202,17 @@ void GuiMenu::newWin()
 
 	// ˥塼ɥؤΥ٥ȡϥɥ
 
+	gtk_signal_connect( GTK_OBJECT( mMenuWin ),
+			"delete_event",
+			GTK_SIGNAL_FUNC( handle_menu_win_delete ),
+			this );
 	gtk_signal_connect( GTK_OBJECT( mMenuWin ),
 			"destroy",
 			GTK_SIGNAL_FUNC( handle_menu_win_destroy ),
 			this );
+	gtk_signal_connect( GTK_OBJECT( mMenuWin ),
+			"key-press-event",
+			GTK_SIGNAL_FUNC( handleKeyPress ), NULL );
 
 	// ľܥåκ
 
@@ -797,7 +807,7 @@ void GuiMenu::setMouseDfltMenu( long sel_n )
 		return;
 	if( sel_n >= MENU_MAX_N_PER_PAGE )
 		return;
-	if( !bFlagSetMouseDfltMenu )
+	if( !get_flg_move_crsr_dflt() )
 		return;
 
 	long x = 0;
@@ -813,23 +823,59 @@ void GuiMenu::setMouseDfltMenu( long sel_n )
 	y += (long)(aBtnMenu[sel_n]->getProperty( WSNy ));
 	w = (long)(aBtnMenu[sel_n]->getProperty( WSNwidth ));
 	h = (long)(aBtnMenu[sel_n]->getProperty( WSNheight ));
-#endif // D_WS
-
-#ifdef D_GTK
-//@@@
-#endif // D_GTK
 
 	x += w * 4 / 5;
 	y += h / 2;
 
-#ifdef D_WS
 	WSDmouse *mouse = WSGIappMouse();
 	mouse->setMousePosition( x, y );
 #endif // D_WS
 
 #ifdef D_GTK
-//@@@
+	gint menuX = 0;
+	gint menuY = 0;
+	gdk_window_get_position( mMenuWin->window, &menuX, &menuY );
+	if( (menuX <= 32) && (menuY <= 32) )
+		return;
+
+	x = aBtnMenu[sel_n]->allocation.x + menuX;
+	y = aBtnMenu[sel_n]->allocation.y + menuY;
+	w = aBtnMenu[sel_n]->allocation.width;
+	h = aBtnMenu[sel_n]->allocation.height;
+
+	int crsrX = 0;
+	int crsrY = 0;
+	Window rootWin, childWin;
+	int winX, winY;
+	unsigned int mask;
+	XQueryPointer( gdk_x11_get_default_xdisplay(),
+			GDK_ROOT_WINDOW(), &rootWin, &childWin,
+			&crsrX, &crsrY, &winX, &winY, &mask );
+
+	x -= crsrX;
+	y -= crsrY;
+
+	x += w * 4 / 5;
+	y += h / 2;
+
+	XWarpPointer( gdk_x11_get_default_xdisplay(),
+			None, None,
+			0, 0, 0, 0, x, y );
 #endif // D_GTK
+
+#ifdef D_MFC
+	RECT rect;
+	aBtnMenu[sel_n]->GetWindowRect( &rect );
+	x = rect.left;
+	y = rect.top;
+	w = rect.right - rect.left;
+	h = rect.bottom - rect.top;
+
+	x += w * 4 / 5;
+	y += h / 2;
+
+	::SetCursorPos( x, y );
+#endif // D_MFC
 }
 
 ////////////////////////////////////////////////////////////////
@@ -853,24 +899,38 @@ char	GuiMenu::getAccelKey( long n )
 ////////////////////////////////////////////////////////////////
 
 #ifdef D_WS
-
 void EpGuiMenuSel( WSCbase *obj )
 {
 	WSDmouse *mouse = WSGIappMouse();
 
 	if( mouse->getTargetBtn() & WS_MOUSE_BTN1 ){
-		char s[4 + 1];
-		s[0] = (char)(obj->getVariantData( "accel_key" ));
-		s[1] = '\0';
-
-		gKey.setString( s );
+		gKey.setChar( (char)(obj->getVariantData( "accel_key" )) );
 	} else if( mouse->getTargetBtn() & WS_MOUSE_BTN3 ){
-		gKey.setString( "0" );
+		gKey.setChar( '0' );
 	}
 }
-
 #endif // D_WS
 
+////////////////////////////////////////////////////////////////
+// ˥塼ɥĤΥϥɥ
+// GtkWidget *widget : ˥塼ɥ
+// gpointer data : ϿϤ줿
+////////////////////////////////////////////////////////////////
+
+#ifdef D_GTK
+gint handle_menu_win_delete(
+	GtkWidget *widget, gpointer data
+)
+{
+	if( data == NULL )
+		return 0;
+
+	((GuiMenu *)data)->wipe();
+
+	return 0;
+}
+#endif // D_GTK
+
 ////////////////////////////////////////////////////////////////
 // ˥塼ɥκΥ٥ȡϥɥ
 // GtkWidget *widget : ˥塼ɥ
@@ -907,14 +967,14 @@ gint handle_menu_page_release(
 
 	if( event->button == GuiMenu::MOUSE_BUTTON_N_LEFT ){
 		if( d <= -1 )
-			gKey.setString( "4" );
+			gKey.setChar( '4' );
 		if( d >= +1 )
-			gKey.setString( "6" );
+			gKey.setChar( '6' );
 	} else if( event->button == GuiMenu::MOUSE_BUTTON_N_RIGHT ){
 		if( d <= -1 )
-			gKey.setString( "6" );
+			gKey.setChar( '6' );
 		if( d >= +1 )
-			gKey.setString( "4" );
+			gKey.setChar( '4' );
 	}
 
 	return 0;
@@ -933,7 +993,7 @@ gint handle_menu_cancel_release(
 	GtkWidget *widget, GdkEventButton *event, gpointer data
 )
 {
-	gKey.setString( "0" );
+	gKey.setChar( '0' );
 
 	return 0;
 }
@@ -951,7 +1011,7 @@ gint handle_menu_cancel_all_release(
 	GtkWidget *widget, GdkEventButton *event, gpointer data
 )
 {
-	gKey.setString( "/" );
+	gKey.setChar( '/' );
 
 	return 0;
 }
@@ -1011,7 +1071,7 @@ gint handle_menu_button_release(
 	if( event->button == GuiMenu::MOUSE_BUTTON_N_LEFT ){
 		gKey.setChar( gGuiMenu.getAccelKey( (long)data ) );
 	} else if( event->button == GuiMenu::MOUSE_BUTTON_N_RIGHT ){
-		gKey.setString( "0" );
+		gKey.setChar( '0' );
 	}
 
 	return 0;
