@@ -25,26 +25,15 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: GuiMessage.cpp,v 1.49 2009/03/04 11:47:40 bowkenken Exp $
+* $Id: GuiMessage.cpp,v 1.50 2009/07/03 10:36:42 bowkenken Exp $
 ***************************************************************/
 
 ////////////////////////////////////////////////////////////////
 // åɥ
 ////////////////////////////////////////////////////////////////
 
-#include "gmain.h"
-#include "GuiMessage.h"
-#include "GlobalVar.h"
-
-#ifdef D_GTK
-# include "main-gtk-prot.h"
-#endif // D_GTK
-
-#ifdef D_MFC
-# include "xlnl-dows/stdafx.h"
-# include "xlnl-dows/xlnl-dows.h"
-# include "xlnl-dows/MessageWnd.h"
-#endif // D_MFC
+#define GUI_MESSAGE_CPP
+#include "inc.h"
 
 ////////////////////////////////////////////////////////////////
 
@@ -189,6 +178,9 @@ void GuiMessage::newWin()
 			"expose_event",
 			GTK_SIGNAL_FUNC( handle_message_expose ),
 			this );
+	gtk_signal_connect( GTK_OBJECT( mMessageWin ),
+			"key-press-event",
+			GTK_SIGNAL_FUNC( handleKeyPress ), NULL );
 
 	// 襨ꥢ
 
