@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: GuiMessage.h,v 1.22 2009/01/04 00:26:03 bowkenken Exp $
+* $Id: GuiMessage.h,v 1.23 2009/07/03 10:36:42 bowkenken Exp $
 ***************************************************************/
 
 #ifndef GUI_MESSAGE_H
@@ -35,8 +35,14 @@
 // åɥ
 ////////////////////////////////////////////////////////////////
 
-#define GUI_MESSAGE_CPP
-#include "inc.h"
+#ifdef D_GTK
+# include <gtk/gtk.h>
+# include "GtkWSCstring.h"
+#endif // D_GTK
+
+#ifdef D_MFC
+# include "MfcWSCstring.h"
+#endif // D_MFC
 
 ////////////////////////////////////////////////////////////////
 
