@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: GuiSkillEdit.cpp,v 1.7 2009/06/01 06:29:57 bowkenken Exp $
+* $Id: GuiSkillEdit.cpp,v 1.9 2009/07/11 03:24:57 bowkenken Exp $
 ***************************************************************/
 
 ////////////////////////////////////////////////////////////////
@@ -192,6 +192,18 @@ void GuiSkillEdit::newWin()
 		gtk_widget_show( mLabelRate[i] );
 	}
 
+	// ҥȡ٥κ
+
+	mLabelHint = gtk_label_new( "" );
+	if( mLabelHint == NULL ){
+		print_msg( FLG_MSG_ERR,
+				"gtk_label_new()" );
+		return;
+	}
+	gtk_box_pack_start( GTK_BOX( vBoxWin ), mLabelHint,
+			FALSE, TRUE, 2 );
+	gtk_widget_show( mLabelHint );
+
 	// ܥåκ
 
 	GtkWidget *hBox = gtk_hbox_new( FALSE, 0 );
@@ -369,6 +381,11 @@ void GuiSkillEdit::redraw()
 	if( nSlot > -1 )
 		mSkillKind = classData->skill[nSlot];
 
+#ifdef D_GTK
+	gtk_label_set_text( GTK_LABEL( mLabelHint ),
+			get_skill_hint( mSkillKind ) );
+#endif // D_GTK
+
 #ifdef D_MFC
 	CStatic *label = (CStatic *)mSkillEditWin->GetDlgItem(
 			IDC_SKILL_EDIT_HINT );
@@ -440,7 +457,11 @@ void GuiSkillEdit::skillClicked( long nSlot )
 		n = EDIT_SKILL_B_00 + (nSlot % SKILL_PER_PAGE_MAX_N);
 
 	set_edit_skill_n( (edit_skill_t)n );
-	gKey.setChar( '\n' );
+
+	if( get_flg_space_select() )
+		gKey.setChar( ' ' );
+	else
+		gKey.setChar( '\n' );
 }
 
 ////////////////////////////////////////////////////////////////
@@ -452,7 +473,11 @@ void GuiSkillEdit::prevClicked()
 	setClassName();
 
 	set_edit_skill_n( EDIT_SKILL_PREV );
-	gKey.setChar( '\n' );
+
+	if( get_flg_space_select() )
+		gKey.setChar( ' ' );
+	else
+		gKey.setChar( '\n' );
 }
 
 ////////////////////////////////////////////////////////////////
@@ -464,7 +489,11 @@ void GuiSkillEdit::nextClicked()
 	setClassName();
 
 	set_edit_skill_n( EDIT_SKILL_NEXT );
-	gKey.setChar( '\n' );
+
+	if( get_flg_space_select() )
+		gKey.setChar( ' ' );
+	else
+		gKey.setChar( '\n' );
 }
 
 ////////////////////////////////////////////////////////////////
