@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: GuiWords.cpp,v 1.10 2009/06/24 10:44:49 bowkenken Exp $
+* $Id: GuiWords.cpp,v 1.11 2009/07/03 10:36:42 bowkenken Exp $
 ***************************************************************/
 
 ////////////////////////////////////////////////////////////////
@@ -102,6 +102,9 @@ void GuiWords::newWin()
 			"destroy",
 			GTK_SIGNAL_FUNC( handle_words_destroy ),
 			this );
+	gtk_signal_connect( GTK_OBJECT( mWordsWin ),
+			"key-press-event",
+			GTK_SIGNAL_FUNC( handleKeyPress ), NULL );
 
 	// ܥåκ
 
