@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: GuiWords.h,v 1.4 2009/01/04 00:26:03 bowkenken Exp $
+* $Id: GuiWords.h,v 1.5 2009/06/24 02:44:39 bowkenken Exp $
 ***************************************************************/
 
 #ifndef GUI_WORDS_H
@@ -75,7 +75,7 @@ public:
 	void init();
 	void destroy();
 
-	void draw( const char *str, long w = -1 );
+	void draw( const char *name, const char *str, long w = -1 );
 	void redraw();
 	void wipe();
 
