@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: Key.cpp,v 1.20 2009/02/19 03:42:31 bowkenken Exp $
+* $Id: Key.cpp,v 1.23 2009/07/04 08:17:15 bowkenken Exp $
 ***************************************************************/
 
 ////////////////////////////////////////////////////////////////
@@ -58,7 +58,7 @@ static WSCbool handler( long keyCode, WSCbool flagOn )
 			key = keyCode;
 		}
 
-		gKey.setChar( key, true );
+		gKey.setChar( key, true, true );
 		return false;
 	}
 	if( (WSK_A <= keyCode) && (keyCode <= WSK_Z) ){
@@ -68,7 +68,7 @@ static WSCbool handler( long keyCode, WSCbool flagOn )
 			key = keyCode;
 		}
 
-		gKey.setChar( key, true );
+		gKey.setChar( key, true, true );
 		return false;
 	}
 
@@ -225,7 +225,7 @@ static WSCbool handler( long keyCode, WSCbool flagOn )
 		break;
 	}
 
-	gKey.setChar( key, true );
+	gKey.setChar( key, true, true );
 	return false;
 }
 
@@ -442,12 +442,12 @@ gboolean handleKeyPress(
 	case GDK_F35:
 		char buf[15 + 1];
 		sprintf( buf, "&%2ld", key - GDK_F1 + 1 );
-		gKey.setString( buf, true );
+		gKey.setString( buf, true, true );
 
 		return 1;
 	}
 
-	gKey.setChar( key, true );
+	gKey.setChar( key, true, true );
 
 	return 1;
 }
@@ -632,20 +632,6 @@ void Key::init()
 #ifdef D_WS
 	WSGIappKeyboard()->setGlobalKeyHook( handler );
 #endif // D_WS
-
-#ifdef D_GTK
-	// ᥤ󡦥ɥؤΥ٥ȡϥɥ
-
-	gtk_signal_connect( GTK_OBJECT( gMapWin ),
-			"key-press-event",
-			GTK_SIGNAL_FUNC( handleKeyPress ), NULL );
-
-	// ˥塼ɥؤΥ٥ȡϥɥ
-
-	gtk_signal_connect( GTK_OBJECT( gGuiMenu.mMenuWin ),
-			"key-press-event",
-			GTK_SIGNAL_FUNC( handleKeyPress ), NULL );
-#endif // D_GTK
 }
 
 ////////////////////////////////////////////////////////////////
@@ -667,27 +653,29 @@ long Key::getChar()
 ////////////////////////////////////////////////////////////////
 // Хåեˣʸɲ
 // long c : 
+// bool flagMacro : ޥŸ뤫?
 // bool flagCheckClear : ԡȤХåե
 //                       ޤʤͤˤ뤫
 ////////////////////////////////////////////////////////////////
 
-void Key::setChar( long c, bool flagCheckClear )
+void Key::setChar( long c, bool flagMacro, bool flagCheckClear )
 {
 	char s[4 + 1] = "";
 	s[0] = (char)c;
 	s[1] = '\0';
 
-	setString( s, flagCheckClear );
+	setString( s, flagMacro, flagCheckClear );
 }
 
 ////////////////////////////////////////////////////////////////
 // Хåեʸɲ
 // WSCstring s : ʸ
+// bool flagMacro : ޥŸ뤫?
 // bool flagCheckClear : ԡȤХåե
 //                       ޤʤͤˤ뤫
 ////////////////////////////////////////////////////////////////
 
-void Key::setString( WSCstring s, bool flagCheckClear )
+void Key::setString( WSCstring s, bool flagMacro, bool flagCheckClear )
 {
 	if( flagCheckClear && g_flg_clr_key_buf ){
 		static long gPreChar = -1;
@@ -714,7 +702,7 @@ void Key::setString( WSCstring s, bool flagCheckClear )
 	switch( g_gui_key_kind ){
 	case GUI_KEY_KIND_CONSOLE:
 	case GUI_KEY_KIND_KEY_BUF_INTERRUPT:
-		setStringKeyTab( s );
+		setStringKeyTab( s, flagMacro );
 		break;
 	case GUI_KEY_KIND_CLASS_KEY:
 		buf += s;
@@ -726,10 +714,11 @@ void Key::setString( WSCstring s, bool flagCheckClear )
 
 ////////////////////////////////////////////////////////////////
 // Хåեʸɲ
+// bool flagMacro : ޥŸ뤫?
 // WSCstring s : ʸ
 ////////////////////////////////////////////////////////////////
 
-void Key::setStringKeyTab( WSCstring s )
+void Key::setStringKeyTab( WSCstring s, bool flagMacro )
 {
 	char **tab = get_key_tab();
 
@@ -737,8 +726,7 @@ void Key::setStringKeyTab( WSCstring s )
 		long c;
 		c = s[0];
 
-		bool bFlgTab;
-		bFlgTab = true;
+		bool bFlgTab = true;
 
 		if( c <= '\0' )
 			bFlgTab = false;
@@ -746,6 +734,8 @@ void Key::setStringKeyTab( WSCstring s )
 			bFlgTab = false;
 		if( tab[c] == NULL )
 			bFlgTab = false;
+		if( !flagMacro )
+			bFlgTab = false;
 
 		if( bFlgTab ){
 			set_key_buf_str_tail( tab[c] );
