@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: MouseMap.cpp,v 1.36 2009/05/28 08:44:49 bowkenken Exp $
+* $Id: MouseMap.cpp,v 1.37 2009/07/04 01:23:58 bowkenken Exp $
 ***************************************************************/
 
 ////////////////////////////////////////////////////////////////
@@ -266,9 +266,7 @@ void funcMotionPoint(
 
 	// ơС˥ҥȤɽ
 
-	printMapStatBar( "%s    %s",
-			get_str_map_hint_obj( mapX, mapY ),
-			get_str_map_hint_chr( mapX, mapY ) );
+	guiMapPrintStatBarHint();
 }
 
 ////////////////////////////////////////////////////////////////
