@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: WinPos.cpp,v 1.17 2009/05/12 00:34:56 bowkenken Exp $
+* $Id: WinPos.cpp,v 1.18 2009/07/11 13:57:28 bowkenken Exp $
 ***************************************************************/
 
 ////////////////////////////////////////////////////////////////
@@ -44,10 +44,10 @@
 WinPos::WinPos()
 {
 	flagDraw = false;
-	x = 0;
-	y = 0;
-	w = -1;
-	h = -1;
+	mX = 0;
+	mY = 0;
+	mW = -1;
+	mH = -1;
 }
 
 ////////////////////////////////////////////////////////////////
@@ -166,13 +166,13 @@ void WinPos::set(
 	long *pw, long *ph )
 {
 	if( px != NULL )
-		x = *px;
+		mX = *px;
 	if( py != NULL )
-		y = *py;
+		mY = *py;
 	if( pw != NULL )
-		w = *pw;
+		mW = *pw;
 	if( ph != NULL )
-		h = *ph;
+		mH = *ph;
 
 	if( flagDraw )
 		draw( kind );
@@ -192,66 +192,80 @@ void WinPos::get(
 	long *px, long *py,
 	long *pw, long *ph )
 {
+	if( flagDraw )
+		calc( kind );
+
+	if( px != NULL )
+		*px = mX;
+	if( py != NULL )
+		*py = mY;
+	if( pw != NULL )
+		*pw = mW;
+	if( ph != NULL )
+		*ph = mH;
+}
+
+////////////////////////////////////////////////////////////////
+// ɥκɸ׻
+// win_kind_t kind : ɥμ
+////////////////////////////////////////////////////////////////
+
+void WinPos::calc( win_kind_t kind )
+{
+	if( !flagDraw )
+		return;
+
 	void *pWin = getWin( kind );
+	if( pWin == NULL )
+		return;
 
-	if( (pWin != NULL) && flagDraw ){
 #ifdef D_WS
 //@@@
 #endif // D_WS
 
 #ifdef D_GTK
-		gint gx, gy, gw, gh;
-		gint fx, fy, fd;
-		gint bgnX, bgnY, endX, endY;
+	gint gx, gy, gw, gh;
+	gint fx, fy, fd;
+	gint posX, posY, bgnX, bgnY, endX, endY;
 
-		GdkWindow *win = GTK_WIDGET( pWin )->window;
+	GdkWindow *win = GTK_WIDGET( pWin )->window;
 
-		// ɸ
+	// ɸ
 
-		gdk_window_get_position( win, &gx, &gy );
-		gdk_window_get_deskrelative_origin( win, &fx, &fy );
-		gdk_window_get_root_origin( win, &bgnX, &bgnY );
-		gdk_window_get_origin( win, &endX, &endY );
+	gdk_window_get_position( win, &posX, &posY );
+	gdk_window_get_deskrelative_origin( win, &fx, &fy );
+	gdk_window_get_root_origin( win, &bgnX, &bgnY );
+	gdk_window_get_origin( win, &endX, &endY );
 
-		if( g_flg_gnome )
-			fd = 0;
-		else
-			fd = fx - bgnX;
+	if( g_flg_gnome )
+		fd = 0;
+	else
+		fd = fx - bgnX;
 
-		gx -= endX - bgnX - fd;
-		gy -= endY - bgnY - fd;
+	gx = posX - (endX - bgnX - fd);
+	gy = posY - (endY - bgnY - fd);
 
-		// 
+	// 
 
-		gdk_window_get_size( win, &gw, &gh );
+	gdk_window_get_size( win, &gw, &gh );
 
-		// 
+	// 
 
-		x = gx;
-		y = gy;
-		w = gw;
-		h = gh;
+	mX = gx;
+	mY = gy;
+	mW = gw;
+	mH = gh;
 #endif //D_GTK
 
 #ifdef D_MFC
-		CRect rect;
-		((CWnd *)pWin)->GetWindowRect( &rect );
+	CRect rect;
+	((CWnd *)pWin)->GetWindowRect( &rect );
 
-		x = rect.left;
-		y = rect.top;
-		w = rect.Width();
-		h = rect.Height();
+	mX = rect.left;
+	mY = rect.top;
+	mW = rect.Width();
+	mH = rect.Height();
 #endif //D_MFC
-	}
-
-	if( px != NULL )
-		*px = x;
-	if( py != NULL )
-		*py = y;
-	if( pw != NULL )
-		*pw = w;
-	if( ph != NULL )
-		*ph = h;
 }
 
 ////////////////////////////////////////////////////////////////
@@ -273,8 +287,8 @@ void WinPos::draw( win_kind_t kind, bool flagDlg )
 	gtk_widget_show( GTK_WIDGET( pWin ) );
 
 	if( g_flg_set_win_pos ){
-		gdk_window_move( GTK_WIDGET( pWin )->window, x, y );
-		gdk_window_resize( GTK_WIDGET( pWin )->window, w, h );
+		gdk_window_move( GTK_WIDGET( pWin )->window, mX, mY );
+		gdk_window_resize( GTK_WIDGET( pWin )->window, mW, mH );
 	}
 
 	gdk_window_raise( GTK_WIDGET( pWin )->window );
@@ -285,18 +299,22 @@ void WinPos::draw( win_kind_t kind, bool flagDlg )
 		CRect rect;
 		((CWnd *)pWin)->GetWindowRect( &rect );
 
-		w = rect.Width();
-		h = rect.Height();
+		mW = rect.Width();
+		mH = rect.Height();
 
 		if( g_flg_set_win_pos ){
-			if( (w > 0) && (h > 0) )
-				((CDialog *)pWin)->MoveWindow( x, y, w, h );
+			if( (mW > 0) && (mH > 0) ){
+				((CDialog *)pWin)->MoveWindow(
+						mX, mY, mW, mH );
+			}
 		}
 	} else {
 		((CWnd *)pWin)->ShowWindow( SW_SHOW );
 		if( g_flg_set_win_pos ){
-			if( (w > 0) && (h > 0) )
-				((CWnd *)pWin)->MoveWindow( x, y, w, h );
+			if( (mW > 0) && (mH > 0) ){
+				((CWnd *)pWin)->MoveWindow(
+						mX, mY, mW, mH );
+			}
 		}
 		((CWnd *)pWin)->BringWindowToTop();
 		((CWnd *)pWin)->UpdateWindow();
@@ -313,58 +331,25 @@ void WinPos::draw( win_kind_t kind, bool flagDlg )
 
 void WinPos::wipe( win_kind_t kind, bool flagDlg )
 {
+	flagDraw = false;
+
 	void *pWin = getWin( kind );
 	if( pWin == NULL )
 		return;
 
+	calc( kind );
+
 #ifdef D_WS
 //@@@
 	pWin->setVisible( false );
 #endif // D_WS
 
 #ifdef D_GTK
-	gint gx, gy, gw, gh;
-	gint bgnX, bgnY, endX, endY;
-
-	GdkWindow *win = GTK_WIDGET( pWin )->window;
-
-	// ɸ
-
-	gdk_window_get_position( win, &gx, &gy );
-	gdk_window_get_root_origin( win, &bgnX, &bgnY );
-	gdk_window_get_origin( win, &endX, &endY );
-
-	gx -= endX - bgnX;
-	gy -= endY - bgnY;
-
-	// 
-
-	gdk_window_get_size( win, &gw, &gh );
-
-	// 
-
-	x = gx;
-	y = gy;
-	w = gw;
-	h = gh;
-
-	//
-
 	gtk_widget_hide( GTK_WIDGET( pWin ) );
 #endif //D_GTK
 
 #ifdef D_MFC
-	CRect rect;
-	((CWnd *)pWin)->GetWindowRect( &rect );
-
-	x = rect.left;
-	y = rect.top;
-	w = rect.Width();
-	h = rect.Height();
-
 	if( !flagDlg )
 		((CWnd *)pWin)->ShowWindow( SW_HIDE );
 #endif //D_MFC
-
-	flagDraw = false;
 }
