@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: call.cpp,v 1.106 2009/06/24 02:44:28 bowkenken Exp $
+* $Id: call.cpp,v 1.107 2009/07/04 01:24:13 bowkenken Exp $
 ***************************************************************/
 
 #define	CALL_CPP
@@ -157,6 +157,26 @@ void	call_gui_map_cont_exec_set( bool_t flagExec )
 #endif // D_GTK
 }
 
+/***************************************************************
+* ơС˥ҥȤɽ
+***************************************************************/
+
+void	call_gui_map_print_stat_bar_hint( void )
+{
+#if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
+	if( !g_flg_init )
+		return;
+	if( !g_flg_gui )
+		return;
+
+	gui_begin();
+
+	guiMapPrintStatBarHint();
+
+	gui_end();
+#endif
+}
+
 /***************************************************************
 * ˥塼ɥ
 * draw_menu_t *data : ˥塼ѥǡ
