@@ -6,6 +6,7 @@ extern "C" {
 
 void	init_draw( void );
 void	reset_static_draw( void );
+void	ver_up_draw_ver_1_2_22( void );
 void	measure_clk_tck( void );
 void	print_wrn( const char *s, ... );
 void	print_err( const char *s, ... );
@@ -18,6 +19,18 @@ void	print_words(
 	const char *fmt_male,
 	...
 );
+void	print_words_win(
+	const char *name,
+	sex_t sex,
+	const char *fmt_female,
+	const char *fmt_male,
+	...
+);
+void	print_words_sub(
+	bool_t flg_draw_win,
+	const char *name,
+	const char *buf
+);
 const char	*get_words_line( const char *p, long draw_max_n );
 const char	*get_next_char_str( const char *p );
 long	get_next_char_len( const char *p );
@@ -38,7 +51,9 @@ long	get_ls_msg_n( void );
 void	draw_ls_msg( long n );
 ls_msg_t	*get_ls_msg( long idx );
 void	print_str( long scrn_x, long scrn_y, const char *s, ... );
-void	print_vfx( long scrn_x, long scrn_y, const char *s, ... );
+bool_t	print_vfx( long scrn_x, long scrn_y, const char *s, ... );
+bool_t	print_vfx_cui( long scrn_x, long scrn_y, const char *s, ... );
+void	wipe_vfx( long map_x, long map_y, long dx, long dy );
 bool_t	set_redraw_every_turn( bool_t flg );
 bool_t	chk_redraw_every_turn( void );
 void	wipe_all( void );
@@ -76,6 +91,7 @@ bool_t	wipe_menu( void );
 void	draw_all_mbr_stat( void );
 void	draw_mbr_stat( mbr_t *mbr );
 void	draw_misc_stat( void );
+const char	*get_stat_dun_lev_str( void );
 void	draw_misc_stat_time( bool_t flg_force );
 bool_t	vfx_spell( spell_tab_t *tab, long arw_n, pos_t bgn[], pos_t end[] );
 void	vfx_spell_typhoon( void );
@@ -84,9 +100,9 @@ bool_t	vfx_spell_conflagration_sub( long x, long y, long height );
 void	vfx_spell_earthquake( void );
 void	vfx_spell_thunder( long arw_n, pos_t end[] );
 void	vfx_spell_inundation( void );
-void	vfx_hit( chr_kind_t kind, long x, long y );
-void	vfx_crtcl( chr_kind_t kind, long x, long y );
-void	vfx_ninja_crtcl( chr_kind_t kind, long x, long y );
+void	vfx_hit( chr_t *chr, long x, long y );
+void	vfx_crtcl( chr_t *chr, long x, long y );
+void	vfx_ninja_crtcl( chr_t *chr, long x, long y );
 void	get_vfx_attr( curs_attr_t *attr );
 void	set_vfx_attr( const curs_attr_t *attr );
 void	set_vfx_attr_n( curs_attr_n_t n );
@@ -109,7 +125,7 @@ void	bgn_sync_vfx_num( void );
 void	end_sync_vfx_num( void );
 long	get_draw_num_frame( long len );
 long	get_draw_num_sync_max_len( void );
-void	draw_num_sync( long idx );
+bool_t	draw_num_sync( long idx );
 void	draw_num( long map_x, long map_y, long n, chr_t *chr );
 void	draw_num_x_1(
 	long map_x, long map_y,
@@ -122,8 +138,19 @@ void	draw_blast(
 	long map_x, long map_y,
 	blast_t *p, char *str
 );
+void	draw_blast_cui(
+	chr_kind_t kind,
+	long map_x, long map_y,
+	blast_t *p, char *str
+);
+void	draw_blast_sub(
+	bool_t flg_cui,
+	chr_kind_t kind,
+	long map_x, long map_y,
+	blast_t *p, char *str
+);
 void	draw_request( request_t *req );
-void	draw_words( const char *words );
+void	draw_words( const char *name, const char *words, ... );
 void	redraw_mbr_data( mbr_t *org, mbr_t *mbr, long page_n );
 void	draw_mbr_data_all( mbr_t *org, mbr_t *mbr, long page_n );
 void	draw_mbr_data_all_cui( mbr_t *org, mbr_t *mbr, long page_n );
@@ -137,6 +164,7 @@ bool_t	gets_mbr_name( mbr_t *mbr );
 bool_t	gets_mbr_face( mbr_t *mbr );
 bool_t	gets_race_name( mbr_t *mbr );
 bool_t	gets_pet_name( pet_t *pet );
+void	print_skill_hint( long x, long y, skill_kind_t kind );
 void	draw_edit_class_all(
 	class_t *org, class_t *dst,
 	edit_class_t sel_n, bool_t flg_sel_add
@@ -145,7 +173,16 @@ void	draw_edit_class(
 	class_t *org, class_t *dst, edit_class_t n,
 	bool_t flg_sel, bool_t flg_sel_add
 );
+void	draw_edit_skill_all(
+	class_t *org, class_t *dst,
+	edit_skill_t sel_n
+);
+void	draw_edit_skill(
+	class_t *org, class_t *dst, edit_skill_t n,
+	bool_t flg_sel
+);
 bool_t	gets_class_name( char *name );
+bool_t	gets_item_alias( char *name );
 bool_t	gets_auto_mark_info( char *name );
 bool_t	gets_auto_mark_hint( char *name );
 bool_t	gets_line( const char *prompt, char *s, long max_len );
@@ -170,6 +207,9 @@ flg_vfx_mnstr_t	get_flg_vfx_mnstr( void );
 flg_vfx_mnstr_t	set_flg_vfx_mnstr( flg_vfx_mnstr_t flg );
 void	wait_clock( long frame );
 void	wait_frame( long frame );
+void	wait_100_n_msec( long n );
+void	wait_100_msec( void );
+void	sleep_msec( long n );
 void	set_flg_break_key( bool_t flg_break );
 bool_t	chk_flg_break_key( void );
 long	read_char( long *p );
@@ -197,10 +237,15 @@ long	get_key_half_wait( bool_t *p_flg_cont_exec );
 long	get_key_std( bool_t *p_flg_cont_exec );
 long	get_key_no_clr( bool_t *p_flg_cont_exec );
 long	get_key_no_clr_default( bool_t *p_flg_cont_exec );
+long	get_key_no_wait( void );
 bool_t	chk_key_buf( void );
 long	get_key_buf_char( void );
 long	get_key_buf_char_sub( void );
-bool_t	set_key_buf_str( const char *s );
+bool_t	set_key_buf_char_head( long c );
+bool_t	set_key_buf_char_tail( long c );
+bool_t	set_key_buf_str_head( const char *s );
+bool_t	set_key_buf_str_tail( const char *s );
+bool_t	cv_key_buf_char_tail( long dst, long src );
 long	get_key_tab_n( const char *key );
 char	*get_key_tab_cmd( const char *key );
 char	*get_key_tab_cmd_char( long c );
@@ -209,6 +254,7 @@ void	set_key_tab( const char *key, const char *str );
 void	set_key_tab_char( long c, const char *str );
 long	*get_clk_tck( void );
 bool_t	get_flg_draw_menu( void );
+void	check_memory_draw_c( void );
 
 #ifdef __cplusplus
 }
