@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: dun.c,v 1.151 2009/06/01 05:05:04 bowkenken Exp $
+* $Id: dun.c,v 1.152 2009/06/26 16:58:16 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -96,14 +96,20 @@
 ***************************************************************/
 
 static dun_t	dun;
+check_memory_def( check_memory_dun_c_dun )
 
 static area_t	g_room_ptn_max_n, g_boss_room_ptn_max_n;
+check_memory_def( check_memory_dun_c_g_room_ptn_max_n )
 
 static crsr_ptn_t	g_crsr_ptn, g_crsr_ptn_usr[CRSR_PTN_MAX_N];
+check_memory_def( check_memory_dun_c_g_crsr_ptn )
 static crsr_ptn_t	g_sub_crsr_ptn;
+check_memory_def( check_memory_dun_c_g_sub_crsr_ptn )
 static long	g_crsr_ptn_n, g_crsr_ptn_max_n;
+check_memory_def( check_memory_dun_c_g_crsr_ptn_n )
 
 static long	g_nest_flg_dun;
+check_memory_def( check_memory_dun_c_g_nest_flg_dun )
 
 /***************************************************************
 * ǡե
@@ -4373,3 +4379,23 @@ bool_t	save_dun( void )
 
 	return TRUE;
 }
+
+/***************************************************************
+* ꡼å
+***************************************************************/
+
+void	check_memory_dun_c( void )
+{
+	check_memory( check_memory_dun_c_dun,
+			"dun.c: dun" );
+	check_memory( check_memory_dun_c_g_room_ptn_max_n,
+			"dun.c: g_room_ptn_max_n" );
+	check_memory( check_memory_dun_c_g_crsr_ptn,
+			"dun.c: g_crsr_ptn" );
+	check_memory( check_memory_dun_c_g_sub_crsr_ptn,
+			"dun.c: g_sub_crsr_ptn" );
+	check_memory( check_memory_dun_c_g_crsr_ptn_n,
+			"dun.c: g_crsr_ptn_n" );
+	check_memory( check_memory_dun_c_g_nest_flg_dun,
+			"dun.c: g_nest_flg_dun" );
+}
