@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: ending-space.c,v 1.8 2009/06/23 12:56:26 bowkenken Exp $
+* $Id: ending-space.c,v 1.9 2009/06/26 16:58:16 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -49,6 +49,7 @@ static const long XR = 16384;
 static const long YR = 16384;
 static const long ZR = 256;
 static const long Z_SPEED = -1;
+check_memory_def( check_memory_ending_space_c_XR )
 
 typedef struct {
 	long	x, y, z;
@@ -61,6 +62,7 @@ typedef struct {
 } space_t;
 
 static space_t	g_space;
+check_memory_def( check_memory_ending_space_c_g_space )
 
 /***************************************************************
 * åա
@@ -68,15 +70,19 @@ static space_t	g_space;
 
 static long	g_frame;
 static const long	g_roll_frame_n = 5;
+check_memory_def( check_memory_ending_space_c_g_frame )
 
 // ʸֳ
 static const long	staff_roll_interval_width = 1;
 static const long	staff_roll_interval_height = 2;
+check_memory_def( check_memory_ending_space_c_staff_roll_interval_width )
 
 static long	staff_roll_y;
 static long	staff_roll_max_len;
+check_memory_def( check_memory_ending_space_c_staff_roll_y )
 
 static const long	FLICKER_N = 16;
+check_memory_def( check_memory_ending_space_c_FLICKER_N )
 
 #define STR_THE_END	\
 	"                 The End                  "
@@ -132,8 +138,10 @@ const char	*g_str_staff_roll[] = {
 	STR_THE_END,
 	NULL,
 };
+check_memory_def( check_memory_ending_space_c_g_str_staff_roll )
 
 const char *g_str_the_end = STR_THE_END;
+check_memory_def( check_memory_ending_space_c_g_str_the_end )
 
 /***************************************************************
 * ν
@@ -357,3 +365,27 @@ void	draw_staff_roll_line( long x, long y, const char *str )
 
 	print_str( x, y, MSG_S, str );
 }
+
+/***************************************************************
+* ꡼å
+***************************************************************/
+
+void	check_memory_ending_space_c( void )
+{
+	check_memory( check_memory_ending_space_c_XR,
+			"ending-space.c: XR" );
+	check_memory( check_memory_ending_space_c_g_space,
+			"ending-space.c: g_space" );
+	check_memory( check_memory_ending_space_c_g_frame,
+			"ending-space.c: g_frame" );
+	check_memory( check_memory_ending_space_c_staff_roll_interval_width,
+			"ending-space.c: staff_roll_interval_width" );
+	check_memory( check_memory_ending_space_c_staff_roll_y,
+			"ending-space.c: staff_roll_y" );
+	check_memory( check_memory_ending_space_c_FLICKER_N,
+			"ending-space.c: FLICKER_N" );
+	check_memory( check_memory_ending_space_c_g_str_staff_roll,
+			"ending-space.c: g_str_staff_roll" );
+	check_memory( check_memory_ending_space_c_g_str_the_end,
+			"ending-space.c: g_str_the_end" );
+}
