@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: fight.c,v 1.159 2009/06/01 13:47:35 bowkenken Exp $
+* $Id: fight.c,v 1.162 2009/07/12 09:02:11 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -166,6 +166,7 @@ static attack_t	mbr_attack_bash[] = {
 		SPELL_KIND_NULL,
 		EXTENT_KIND_NULL, N_MSG_NULL, },
 };
+check_memory_def( check_memory_fight_c_mbr_attack_bash )
 
 /***************************************************************
 * ƥꤲιǡ
@@ -185,6 +186,7 @@ static attack_t	mbr_attack_throw[] = {
 		SPELL_KIND_NULL,
 		EXTENT_KIND_NULL, N_MSG_NULL, },
 };
+check_memory_def( check_memory_fight_c_mbr_attack_throw )
 
 /***************************************************************
 * ꤲιǡ
@@ -204,6 +206,7 @@ static attack_t	mbr_attack_throw_light[] = {
 		SPELL_KIND_NULL,
 		EXTENT_KIND_NULL, N_MSG_NULL, },
 };
+check_memory_def( check_memory_fight_c_mbr_attack_throw_light )
 
 /***************************************************************
 * ƥåѿꥻå
@@ -376,8 +379,6 @@ bool_t	fight_throw( chr_t *chr1, chr_t *chr2, attack_t *dflt_attack )
 
 	if( chr1 == NULL )
 		return FALSE;
-	if( chr2 == NULL )
-		return FALSE;
 
 	if( is_mbr( chr1 ) ){
 		eq = get_mbr_item_asgn_equip( chr1 );
@@ -1295,7 +1296,18 @@ bool_t	fight_x_1(
 
 	/* ꤬Ƥ뤫 */
 
-	if( !flg_d_null ){
+	if( flg_d_null ){
+		pos_t	o_pos, d_pos;
+
+		o_pos.x = o_p->x;
+		o_pos.y = o_p->y;
+		d_pos.x = o_p->trgt.true_x;
+		d_pos.y = o_p->trgt.true_y;
+		if( !chk_find( &o_pos, &d_pos ) ){
+			clr_chr_trgt_act( o_p, FALSE );
+			return FALSE;
+		}
+	} else {
 		if( !chk_find_chr( o_p, d_p ) ){
 			if( o_k == CHR_KIND_MBR ){
 				print_msg( FLG_MSG_ERR,
@@ -3358,3 +3370,17 @@ char	*get_msg_attack( const attack_t *attack )
 
 	return MSG_NULL;
 }
+
+/***************************************************************
+* ꡼å
+***************************************************************/
+
+void	check_memory_fight_c( void )
+{
+	check_memory( check_memory_fight_c_mbr_attack_bash,
+			"fight.c: mbr_attack_bash" );
+	check_memory( check_memory_fight_c_mbr_attack_throw,
+			"fight.c: mbr_attack_throw" );
+	check_memory( check_memory_fight_c_mbr_attack_throw_light,
+			"fight.c: mbr_attack_throw_light" );
+}
