@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: gf-conf.c,v 1.20 2009/05/24 09:21:02 bowkenken Exp $
+* $Id: gf-conf.c,v 1.22 2009/07/11 14:22:20 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -361,6 +361,9 @@ bool_t	load_game_conf_set_val(
 	} else if( strcmp( id, "multiple_message_line" ) == 0 ){
 		return load_game_conf_mul_line( id, val );
 
+	} else if( strcmp( id, "move_cursor_to_default" ) == 0 ){
+		return load_game_conf_move_crsr_dflt( id, val );
+
 	} else if( strcmp( id, "joystick_number" ) == 0 ){
 		return load_game_conf_joystick_number( id, val );
 
@@ -724,6 +727,20 @@ bool_t	load_game_conf_mul_line( char *id, long val )
 	return TRUE;
 }
 
+/***************************************************************
+* ˥塼Υǥեȹܤإưư뤫
+* char *id : ̻
+* long val : 祤ƥåֹ
+* return : 顼̵ä?
+***************************************************************/
+
+bool_t	load_game_conf_move_crsr_dflt( char *id, long val )
+{
+	set_flg_move_crsr_dflt( (bool_t)val );
+
+	return TRUE;
+}
+
 /***************************************************************
 * 祤ƥåֹ
 * char *id : ̻
@@ -1840,6 +1857,11 @@ bool_t	save_game_conf_flg( FILE *fp, const ver_t *ver )
 	fprintf( fp, "multiple_message_line = %ld\n",
 			(long)chk_msg_mul_line() );
 
+	fprintf( fp, "\n" );
+	fprintf( fp, "# move cursor to default\n" );
+	fprintf( fp, "move_cursor_to_default = %ld\n",
+			(long)get_flg_move_crsr_dflt() );
+
 	return TRUE;
 }
 
@@ -2475,3 +2497,11 @@ int	cv_name_to_color( char *name )
 
 	return COLOR_WHITE;
 }
+
+/***************************************************************
+* ꡼å
+***************************************************************/
+
+void	check_memory_gf_conf_c( void )
+{
+}
