@@ -160,6 +160,7 @@ long	load_crypt_str( FILE *fp, char *buf, long n );
 long	load_crypt_c( FILE *fp );
 long	load_crypt_c_sub( FILE *fp );
 void	un_load_crypt_c( FILE *fp, long c );
+void	check_memory_gfile_c( void );
 
 #ifdef __cplusplus
 }
@@ -207,6 +208,7 @@ bool_t	load_game_conf_clr_key_buf_menu( char *id, long val );
 bool_t	load_game_conf_space_select( char *id, long val );
 bool_t	load_game_conf_redraw_every_turn( char *id, long val );
 bool_t	load_game_conf_mul_line( char *id, long val );
+bool_t	load_game_conf_move_crsr_dflt( char *id, long val );
 bool_t	load_game_conf_joystick_number( char *id, long val );
 bool_t	load_game_conf_gnome( char *id, long val );
 bool_t	load_game_conf_set_window_position( char *id, long val );
@@ -275,6 +277,7 @@ const char	*cv_joystick_kind_to_name( joy_kind_t k );
 joy_kind_t	cv_joystick_name_to_kind( const char *name );
 char	*cv_color_to_name( int color );
 int	cv_name_to_color( char *name );
+void	check_memory_gf_conf_c( void );
 
 #ifdef __cplusplus
 }
@@ -290,6 +293,7 @@ bool_t	load_crsr_ptn_head( FILE *fp, crsr_ptn_t *ptn );
 bool_t	load_crsr_ptn_misc( FILE *fp, crsr_ptn_t *ptn );
 bool_t	load_crsr_ptn_data( FILE *fp, crsr_ptn_t *ptn );
 bool_t	save_crsr_ptn( crsr_ptn_t *ptn, long max_n );
+void	check_memory_gf_crsr_c( void );
 
 #ifdef __cplusplus
 }
@@ -320,6 +324,7 @@ bool_t	load_graph_conf_set_str(
 	FILE *fp, const ver_t *ver, bool_t flg_err_exit,
 	char *id, char *str
 );
+void	check_memory_gf_gconf_c( void );
 
 #ifdef __cplusplus
 }
@@ -332,6 +337,7 @@ extern "C" {
 
 char	*get_out_map_file_name( char *s );
 bool_t	out_map_file( void );
+void	check_memory_gf_outmap_c( void );
 
 #ifdef __cplusplus
 }
@@ -365,6 +371,7 @@ bool_t	save_game_replay_ver_1( const ver_t *ver, long n );
 bool_t	save_game_replay_contents(
 	FILE *fp, const ver_t *ver, long n
 );
+void	check_memory_gf_replay_c( void );
 
 #ifdef __cplusplus
 }
@@ -778,6 +785,7 @@ bool_t	get_game_data_head_time(
 	char *str, long n,
 	bool_t flg_txt, bool_t flg_replay
 );
+void	check_memory_gf_save_c( void );
 
 #ifdef __cplusplus
 }
@@ -796,6 +804,7 @@ bool_t	save_town_ptn( town_ptn_t *ptn );
 void	save_town_ptn_col_1byte( FILE *fp, town_ptn_t *ptn );
 void	save_town_ptn_col_2byte( FILE *fp );
 void	back_up_town_ptn( void );
+void	check_memory_gf_town_c( void );
 
 #ifdef __cplusplus
 }
