@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: gmain.c,v 1.130 2009/06/03 17:21:26 bowkenken Exp $
+* $Id: gmain.c,v 1.133 2009/06/27 14:47:20 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -61,19 +61,21 @@
 ***************************************************************/
 
 static long	flg_term;
+check_memory_def( check_memory_gmain_c_flg_term )
 
 #if	defined( HAVE_TERMIOS_H )
 static struct termios	pre_tbuf;
 #elif	defined( HAVE_TERMIO_H )
 static struct termio	pre_tbuf;
 #endif
+check_memory_def( check_memory_gmain_c_pre_tbuf )
 
 /***************************************************************
 * 
 ***************************************************************/
 
 #define	OPT_ARG_MAX_LEN	128
-#define	STR_OPT	"GCUN:P:T:D:S:l:k:e:s:p:md:Vvh"
+#define	STR_OPT	"GCUN:P:T:D:S:l:k:e:s:p:cd:m:Vvh"
 
 #ifdef	HAVE_GETOPT_LONG
 static struct option	long_opt[] = {
@@ -90,13 +92,15 @@ static struct option	long_opt[] = {
 	{ "echo-key",      required_argument, NULL, 'e' },
 	{ "use-curses",    required_argument, NULL, 's' },
 	{ "use-keypad",    required_argument, NULL, 'p' },
-	{ "measure-clock", no_argument,       NULL, 'm' },
+	{ "measure-clock", no_argument,       NULL, 'c' },
 	{ "debug",         required_argument, NULL, 'd' },
+	{ "check-memory",  required_argument, NULL, 'm' },
 	{ "version",       no_argument,       NULL, 'V' },
 	{ "help",          no_argument,       NULL, 'h' },
 	{ 0, 0, 0, 0 }
 };
 #endif	/* HAVE_GETOPT_LONG */
+check_memory_def( check_memory_gmain_c_long_opt )
 
 /***************************************************************
 * 
@@ -132,14 +136,17 @@ char	str_usage[] = {
 	"                             ON or OFF\n"
 	"  -p, --use-keypad=FLAG    use cursor key (call keypad):\n"
 	"                             ON or OFF\n"
-	"  -m, --measure-clock      measure frame rate\n"
+	"  -c, --measure-clock      measure frame rate\n"
 #if	defined( DEBUG ) || !defined( NDEBUG )
 	"  -d, --debug=FLAG         set debug mode:\n"
 	"                             ON or OFF\n"
 #endif
+	"  -m, --check-memory=FLAG  check memory:\n"
+	"                             ON or OFF\n"
 	"  -V, -v, --version        display version and exit\n"
 	"  -h, --help               display this help and exit\n"
 };
+check_memory_def( check_memory_gmain_c_str_usage )
 
 /***************************************************************
 * Τν
@@ -391,6 +398,7 @@ void	init_arg( void )
 	g_flg_use_keypad = FALSE;
 
 	g_flg_measure_clk_tck = FALSE;
+	g_flg_check_memory = TRUE;
 
 	g_flg_send_item_exec_turn = FALSE;
 }
@@ -498,12 +506,15 @@ void	chk_arg( int argc, char **argv )
 		case 'p':
 			chk_opt_flg( optarg, &g_flg_use_keypad, TRUE );
 			break;
-		case 'm':
+		case 'c':
 			g_flg_measure_clk_tck = TRUE;
 			break;
 		case 'd':
 			chk_opt_flg( optarg, &g_flg_debug, TRUE );
 			break;
+		case 'm':
+			chk_opt_flg( optarg, &g_flg_check_memory, TRUE );
+			break;
 		case 'V':
 		case 'v':
 			version( stdout );
@@ -680,9 +691,10 @@ void	close_game( long code )
 {
 	close_item();
 
-	curs_move( get_max_line() - 1, SCREEN_MIN_X );
-	reset_scrn();
+	if( !g_flg_use_curs )
+		curs_move( get_max_line() - 1, SCREEN_MIN_X );
 
+	reset_scrn();
 	fflush( stdout );
 	fflush( stderr );
 
@@ -716,7 +728,7 @@ void	about_game( bool_t flg_init )
 				LS_STR_COPYRIGHT );
 		str_max_n_cat( str, MSG_ABOUT_GAME, max_len );
 
-		call_gui_words_draw_width( str, 80 );
+		call_gui_words_draw_width( NULL, str, 80 );
 
 		return;
 	}
@@ -1202,3 +1214,103 @@ void	clr_key_wait_dos( void )
 {
 	set_key_wait_vtime( 0 );
 }
+
+/***************************************************************
+* ꡼å
+* check_memory_t mem : å꡼
+* const char *msg : 顼å
+***************************************************************/
+
+bool_t	check_memory( check_memory_t mem, const char *msg )
+{
+	long	i;
+
+	if( mem == NULL )
+		return FALSE;
+	if( msg == NULL )
+		msg = "";
+
+	for( i = 0; i < CHECK_MEMORY_MAX_LEN / 2; i++ ){
+		if( (mem[i * 2 + 0] == 0xbe) && (mem[i * 2 + 1] == 0xef) )
+			continue;
+
+		print_msg( FLG_MSG_ERR,
+				"memory error: %s: [0x%2lx,0x%2lx]",
+				msg, mem[i * 2 + 0], mem[i * 2 + 1] );
+		return FALSE;
+	}
+
+	return TRUE;
+}
+
+/***************************************************************
+* ƤΥ꡼å
+***************************************************************/
+
+void	check_memory_all( void )
+{
+	check_memory_amenu_c();
+	check_memory_chr_c();
+	check_memory_curs_c();
+	check_memory_draw_c();
+	check_memory_dun_c();
+	check_memory_ending_ep_c();
+	check_memory_ending_space_c();
+	check_memory_fight_c();
+	check_memory_fx_c();
+	check_memory_gf_conf_c();
+	check_memory_gf_crsr_c();
+	check_memory_gf_gconf_c();
+	check_memory_gf_outmap_c();
+	check_memory_gf_replay_c();
+	check_memory_gf_save_c();
+	check_memory_gf_town_c();
+	check_memory_gfile_c();
+	check_memory_gmain_c();
+	check_memory_imenu_c();
+	check_memory_item_c();
+	check_memory_key_item_c();
+	check_memory_last_boss_c();
+#if	defined( D_GTK )
+#elif	defined( D_MFC )
+#elif	defined( D_DOS )
+	check_memory_main_dos_c();
+#else
+	check_memory_main_unix_c();
+#endif
+	check_memory_map_event_c();
+	check_memory_menu_c();
+	check_memory_misc_c();
+	check_memory_mmenu_c();
+	check_memory_mnstr_act_c();
+	check_memory_mnstr_c();
+	check_memory_msg_c();
+	check_memory_nest_flg_c();
+	check_memory_party_c();
+	check_memory_pet_c();
+	check_memory_replay_c();
+	check_memory_request_c();
+	check_memory_scene_c();
+	check_memory_skill_c();
+	check_memory_spell_c();
+	check_memory_tmenu_c();
+	check_memory_town_c();
+	check_memory_trap_c();
+	check_memory_turn_c();
+}
+
+/***************************************************************
+* gmain.c Υ꡼å
+***************************************************************/
+
+void	check_memory_gmain_c( void )
+{
+	check_memory( check_memory_gmain_c_flg_term,
+			"gmain.c: flg_term" );
+	check_memory( check_memory_gmain_c_pre_tbuf,
+			"gmain.c: pre_tbuf" );
+	check_memory( check_memory_gmain_c_long_opt,
+			"gmain.c: long_opt" );
+	check_memory( check_memory_gmain_c_str_usage,
+			"gmain.c: str_usage" );
+}
