@@ -6,6 +6,7 @@ extern "C" {
 
 void	init_item( void );
 void	reset_static_item( void );
+void	reset_item( void );
 void	close_item( void );
 void	init_wpn( void );
 void	init_armor( void );
@@ -451,6 +452,7 @@ ls_identified_t	*get_ring_material_tab( void );
 ls_identified_t	*get_amulet_material_tab( void );
 ls_identified_t	*get_necklace_material_tab( void );
 n_msg_t	*get_acce_material_idx_tab( void );
+void	check_memory_item_c( void );
 
 #ifdef __cplusplus
 }
