@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: main-dows.cpp,v 1.32 2009/06/06 10:19:03 bowkenken Exp $
+* $Id: main-dows.cpp,v 1.34 2009/07/12 11:38:28 bowkenken Exp $
 ***************************************************************/
 
 ////////////////////////////////////////////////////////////////
@@ -138,6 +138,21 @@ void	closeGameGui()
 	gMusic.close();
 }
 
+////////////////////////////////////////////////////////////////
+// ơС˥֤ΥҥȤɽ
+////////////////////////////////////////////////////////////////
+
+void	guiMapPrintStatBarHint( void )
+{
+	pos_t *crsr = get_crsr();
+	if( crsr == NULL )
+		return;
+
+	printMapStatBar( "%s    %s",
+			get_str_map_hint_obj( crsr->x, crsr->y ),
+			get_str_map_hint_chr( crsr->x, crsr->y ) );
+}
+
 ////////////////////////////////////////////////////////////////
 // ơС˥åɽ
 // const char *s : եޥåʸ
