@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: main-gtk.cpp,v 1.66 2009/06/06 10:19:03 bowkenken Exp $
+* $Id: main-gtk.cpp,v 1.71 2009/07/11 13:57:28 bowkenken Exp $
 ***************************************************************/
 
 ////////////////////////////////////////////////////////////////
@@ -37,6 +37,8 @@
 
 ////////////////////////////////////////////////////////////////
 
+#define	FLAG_BTN_MAP_LABEL_IS_NAME	0
+
 #define	TILE_X_SIZE()	(gPcgDun.getTileSizeX( true ))
 #define	TILE_Y_SIZE()	(gPcgDun.getTileSizeY( true ))
 
@@ -54,6 +56,7 @@ GtkWidget *btnMapExec;
 GtkWidget *btnMapAutoMark;
 GtkWidget *btnMapUserMenu;
 GtkWidget *btnMapSpell;
+GtkWidget *btnMapSquare;
 GtkWidget *btnMapCancel;
 GtkWidget *btnMapOk;
 
@@ -133,6 +136,8 @@ void	init_gtk_win( int argc, char **argv )
 {
 	// GTK+ 
 
+	gtk_set_locale();
+
 	g_thread_init( NULL );
 	gdk_threads_init();
 
@@ -237,6 +242,9 @@ void	init_main_win( void )
 			"destroy",
 			GTK_SIGNAL_FUNC( handle_destroy ),
 			NULL );
+	gtk_signal_connect( GTK_OBJECT( gMapWin ),
+			"key-press-event",
+			GTK_SIGNAL_FUNC( handleKeyPress ), NULL );
 
 	// ġ롦С
 
@@ -259,12 +267,27 @@ void	init_main_win( void )
 			MSG_GUI_MAP_EXEC );
 	gMapButtonContExec = gtk_button_new_with_label(
 			MSG_GUI_MAP_CONT_EXEC_OFF );
+
+#if	FLAG_BTN_MAP_LABEL_IS_NAME
 	btnMapAutoMark = gtk_button_new_with_label(
 			MSG_GUI_MAP_AUTO_MARK );
 	btnMapUserMenu = gtk_button_new_with_label(
 			MSG_GUI_MAP_USER_MENU );
 	btnMapSpell = gtk_button_new_with_label(
 			MSG_GUI_MAP_SPELL );
+	btnMapSquare = gtk_button_new_with_label(
+			MSG_GUI_MAP_SQUARE );
+#else
+	btnMapAutoMark = gtk_button_new_with_label(
+			"  /  " );
+	btnMapUserMenu = gtk_button_new_with_label(
+			"  *  " );
+	btnMapSpell = gtk_button_new_with_label(
+			"  -  " );
+	btnMapSquare = gtk_button_new_with_label(
+			"  +  " );
+#endif
+
 	btnMapCancel = gtk_button_new_with_label(
 			MSG_GUI_MAP_CANCEL );
 	btnMapOk = gtk_button_new_with_label(
@@ -290,6 +313,10 @@ void	init_main_win( void )
 			btnMapSpell,
 			MSG_GUI_MAP_TOOL_TIP_SPELL,
 			NULL );
+	gtk_toolbar_append_widget( GTK_TOOLBAR( toolBar ),
+			btnMapSquare,
+			MSG_GUI_MAP_TOOL_TIP_SQUARE,
+			NULL );
 	gtk_toolbar_append_widget( GTK_TOOLBAR( toolBar ),
 			btnMapCancel,
 			MSG_GUI_MAP_TOOL_TIP_CANCEL,
@@ -304,6 +331,7 @@ void	init_main_win( void )
 	gtk_widget_show( btnMapAutoMark );
 	gtk_widget_show( btnMapUserMenu );
 	gtk_widget_show( btnMapSpell );
+	gtk_widget_show( btnMapSquare );
 	gtk_widget_show( btnMapCancel );
 	gtk_widget_show( btnMapOk );
 
@@ -329,6 +357,10 @@ void	init_main_win( void )
 			"clicked",
 			GTK_SIGNAL_FUNC( handle_spell_clicked ),
 			NULL );
+	gtk_signal_connect( GTK_OBJECT( btnMapSquare ),
+			"clicked",
+			GTK_SIGNAL_FUNC( handle_square_clicked ),
+			NULL );
 	gtk_signal_connect( GTK_OBJECT( btnMapCancel ),
 			"clicked",
 			GTK_SIGNAL_FUNC( handle_cancel_clicked ),
@@ -516,6 +548,21 @@ void	closeGameGui()
 	gMusic.close();
 }
 
+////////////////////////////////////////////////////////////////
+// ơС˥֤ΥҥȤɽ
+////////////////////////////////////////////////////////////////
+
+void	guiMapPrintStatBarHint( void )
+{
+	pos_t *crsr = get_crsr();
+	if( crsr == NULL )
+		return;
+
+	printMapStatBar( "%s    %s",
+			get_str_map_hint_obj( crsr->x, crsr->y ),
+			get_str_map_hint_chr( crsr->x, crsr->y ) );
+}
+
 ////////////////////////////////////////////////////////////////
 // ơС˥åɽ
 // const char *s : եޥåʸ
@@ -554,7 +601,7 @@ gint	handle_delete(
 	GtkWidget *widget, GdkEvent *event, gpointer user_data
 )
 {
-	gKey.setChar( 'Q', TRUE );
+	gKey.setChar( 'Q' );
 
 	return TRUE;
 }
@@ -774,7 +821,7 @@ void	handle_exec_clicked(
 	GtkWidget *widget, gpointer *data
 )
 {
-	gKey.setChar( '.', TRUE );
+	gKey.setChar( '.' );
 }
 
 ////////////////////////////////////////////////////////////////
@@ -788,7 +835,7 @@ void	handle_cont_exec_clicked(
 	gpointer user_data
 )
 {
-	gKey.setChar( CMD_KEY_CONT_EXEC, FALSE );
+	gKey.setChar( CMD_KEY_CONT_EXEC, false, false );
 }
 
 ////////////////////////////////////////////////////////////////
@@ -801,7 +848,7 @@ void	handle_auto_mark_clicked(
 	GtkWidget *widget, gpointer *data
 )
 {
-	gKey.setChar( '/', TRUE );
+	gKey.setChar( '/', true );
 }
 
 ////////////////////////////////////////////////////////////////
@@ -814,7 +861,7 @@ void	handle_user_menu_clicked(
 	GtkWidget *widget, gpointer *data
 )
 {
-	gKey.setChar( '*', TRUE );
+	gKey.setChar( '*', true );
 }
 
 ////////////////////////////////////////////////////////////////
@@ -827,7 +874,20 @@ void	handle_spell_clicked(
 	GtkWidget *widget, gpointer *data
 )
 {
-	gKey.setChar( '-', TRUE );
+	gKey.setChar( '-', true );
+}
+
+////////////////////////////////////////////////////////////////
+// ޥåסɥΥܥΥå٥Ƚ
+// GtkWidget *widget : ܥ
+// gpointer data : ϿϤ줿ǡ
+////////////////////////////////////////////////////////////////
+
+void	handle_square_clicked(
+	GtkWidget *widget, gpointer *data
+)
+{
+	gKey.setChar( '+', true );
 }
 
 ////////////////////////////////////////////////////////////////
@@ -843,7 +903,7 @@ void	handle_cancel_clicked(
 	if( chk_scene_group( SCENE_GROUP_N_SEL_GRAPH ) )
 		gSelMbrGraph->cancel();
 	else
-		gKey.setChar( '0' );
+		gKey.setChar( '0', true );
 }
 
 ////////////////////////////////////////////////////////////////
@@ -859,7 +919,7 @@ void	handle_ok_clicked(
 	if( chk_scene_group( SCENE_GROUP_N_SEL_GRAPH ) )
 		gSelMbrGraph->ok();
 	else
-		gKey.setChar( 'M' - '@' );
+		gKey.setChar( 'M' - '@', true );
 }
 
 ////////////////////////////////////////////////////////////////
