@@ -6,6 +6,7 @@ extern "C" {
 
 void	init_var_menu( void );
 void	init_menu( void );
+void	reset_static_menu( void );
 void	init_ls_menu_func( void );
 bool_t	chk_executing_menu( void );
 char	*exec_menu( menu_t *p, menu_t *dflt, char *str_goto );
@@ -16,12 +17,14 @@ bool_t	chk_err_menu_kind( menu_t *ls );
 bool_t	set_menu_check_item( menu_t *p );
 bool_t	set_menu_radio_item( menu_t *ls, menu_t *p );
 ask_t	exec_menu_ask( char *ttl, ask_t dflt, bool_t can_cancel );
+ask_t	exec_menu_ask_no_msg( char *ttl, ask_t dflt, bool_t can_cancel );
 char	*cb_menu_ask_init( menu_t **pp, menu_t **dflt );
 char	*cb_menu_ask_yes( menu_t **pp, menu_t **dflt );
 char	*cb_menu_ask_no( menu_t **pp, menu_t **dflt );
 char	*exec_menu_sel_num( long *p, long min, long max );
 void	sel_menu_clr( draw_menu_t *data );
 menu_t	*sel_menu( menu_t *p, menu_t *dflt );
+menu_t	*sel_menu_sub( menu_t *p, menu_t *dflt );
 long	set_ls_menu(
 	draw_menu_t *data,
 	menu_t *p,
@@ -53,6 +56,10 @@ bool_t	get_flg_chk_menu( void );
 bool_t	get_flg_chk_short_key( void );
 bool_t	get_flg_space_select( void );
 bool_t	set_flg_space_select( bool_t flg );
+long	get_sel_menu_accel_key( void );
+bool_t	get_flg_move_crsr_dflt( void );
+bool_t	set_flg_move_crsr_dflt( bool_t flg );
+void	check_memory_menu_c( void );
 
 #ifdef __cplusplus
 }
