@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: mmenu-tab.h,v 1.46 2009/06/23 05:50:26 bowkenken Exp $
+* $Id: mmenu-tab.h,v 1.47 2009/07/11 13:56:59 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	MMENU_TAB_H
@@ -1055,7 +1055,16 @@ menu_t	ls_menu_main[] = {
 		'G',
 		"",
 		N_MSG_MENU_GUI, "",
-		NULL, NULL,
+		cb_menu_gui, NULL,
+		FLG_NULL,
+	},
+	{
+		"/misc/config/gui/move cursor to default",
+		"<CheckItem>",
+		'C',
+		"",
+		N_MSG_MENU_MOVE_CRSR_DFLT, "",
+		cb_menu_move_crsr_dflt, NULL,
 		FLG_NULL,
 	},
 	{
