@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: msg.c,v 1.42 2009/05/27 06:26:34 bowkenken Exp $
+* $Id: msg.c,v 1.45 2009/06/26 16:58:16 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -77,8 +77,10 @@
 
 /* μ */
 static lang_kind_t	g_lang_kind, g_lang_kind_next;
+check_memory_def( check_memory_msg_c_g_lang_kind )
 /* ͥ褹 */
 static bool_t	g_flg_lang_ls_priority;
+check_memory_def( check_memory_msg_c_g_flg_lang_ls_priority )
 
 /* Υǡ */
 typedef struct {
@@ -120,6 +122,7 @@ static lang_t	lang_tab[LANG_TAB_MAX_N] = {
 		LANG_KIND_MAX_N,
 	},
 };
+check_memory_def( check_memory_msg_c_lang_tab )
 
 /***************************************************************
 * å
@@ -135,6 +138,7 @@ typedef struct {
 /* åơ֥ */
 
 static msg_t	all_lang_msg[LANG_KIND_MAX_N][N_MSG_MAX_N];
+check_memory_def( check_memory_msg_c_all_lang_msg )
 
 /* ֥å 0 */
 
@@ -163,6 +167,7 @@ static msg_t	all_lang_msg_0[LANG_KIND_MAX_N]
 	},
 };
 #undef	SEL_MSG_BLOCK_0
+check_memory_def( check_memory_msg_c_all_lang_msg_0 )
 
 /* ֥å 1 */
 
@@ -191,9 +196,11 @@ static msg_t	all_lang_msg_1[LANG_KIND_MAX_N]
 	},
 };
 #undef	SEL_MSG_BLOCK_1
+check_memory_def( check_memory_msg_c_all_lang_msg_1 )
 
 /* åƤʤåѤΥǡ */
 static bool_t	flg_msg_def[N_MSG_MAX_N];
+check_memory_def( check_memory_msg_c_flg_msg_def )
 
 /***************************************************************
 * åν
@@ -209,6 +216,10 @@ void	init_msg( void )
 
 	flg_exit = FALSE;
 
+#ifdef	HAVE_LOCALE_H
+	setlocale( LC_ALL, "" );
+#endif
+
 	block_bgn_n = 0;
 	block_end_n = N_MSG__MSG_BLOCK_0_END_;
 	for( l = 0; l < LANG_KIND_MAX_N; l++ ){
@@ -638,3 +649,24 @@ long	str_len_draw_japanese_sjis( const char *s )
 	return len;
 }
 
+/***************************************************************
+* ꡼å
+***************************************************************/
+
+void	check_memory_msg_c( void )
+{
+	check_memory( check_memory_msg_c_g_lang_kind,
+			"msg.c: g_lang_kind" );
+	check_memory( check_memory_msg_c_g_flg_lang_ls_priority,
+			"msg.c: g_flg_lang_ls_priority" );
+	check_memory( check_memory_msg_c_lang_tab,
+			"msg.c: lang_tab" );
+	check_memory( check_memory_msg_c_all_lang_msg,
+			"msg.c: all_lang_msg" );
+	check_memory( check_memory_msg_c_all_lang_msg_0,
+			"msg.c: all_lang_msg_0" );
+	check_memory( check_memory_msg_c_all_lang_msg_1,
+			"msg.c: all_lang_msg_1" );
+	check_memory( check_memory_msg_c_flg_msg_def,
+			"msg.c: flg_msg_def" );
+}
