@@ -32,9 +32,10 @@ bool_t	chk_can_not_join_pet( pet_t *p );
 bool_t	join_pet( pet_t *p );
 bool_t	not_join_pet( pet_t *p );
 void	garbage_collection_all_pet( void );
-void	die_pet( pet_t *p );
+void	die_pet( pet_t *p, bool_t flg_msg );
 void	remove_pet( pet_t *p );
 bool_t	dismissal( pet_t *p );
+void	check_memory_pet_c( void );
 
 #ifdef __cplusplus
 }
