@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: pet.c,v 1.66 2009/06/06 08:04:22 bowkenken Exp $
+* $Id: pet.c,v 1.67 2009/06/26 16:58:16 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -39,12 +39,15 @@
 
 /* ѡƥΤĤƤڥåȤΥꥹ */
 static pet_t	*party_pet[PET_MAX_N];
+check_memory_def( check_memory_pet_c_party_pet )
 
 /* ƤΥڥåȤΥꥹ */
 static pet_t	*ls_pet[LS_PET_MAX_N + 1];
+check_memory_def( check_memory_pet_c_ls_pet )
 
 /* ڥåȤΥ꡼ס */
 static pet_t	ls_pet_buf[LS_PET_MAX_N + 1];
+check_memory_def( check_memory_pet_c_ls_pet_buf )
 
 /***************************************************************
 * ڥåȤν
@@ -748,3 +751,17 @@ bool_t	dismissal( pet_t *p )
 
 	return TRUE;
 }
+
+/***************************************************************
+* ꡼å
+***************************************************************/
+
+void	check_memory_pet_c( void )
+{
+	check_memory( check_memory_pet_c_party_pet,
+			"pet.c: party_pet" );
+	check_memory( check_memory_pet_c_ls_pet,
+			"pet.c: ls_pet" );
+	check_memory( check_memory_pet_c_ls_pet_buf,
+			"pet.c: ls_pet_buf" );
+}
