@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: replay.c,v 1.19 2009/01/04 00:24:52 bowkenken Exp $
+* $Id: replay.c,v 1.20 2009/06/26 16:58:16 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -38,20 +38,28 @@
 /***************************************************************/
 
 static long	g_replay_save_slot;
+check_memory_def( check_memory_replay_c_g_replay_save_slot )
 
 static bool_t	g_flg_reg_replay[REPLAY_SLOT_MAX_N];
+check_memory_def( check_memory_replay_c_g_flg_reg_replay )
 static long	g_replay_randm_seed[REPLAY_SLOT_MAX_N];
+check_memory_def( check_memory_replay_c_g_replay_randm_seed )
 static replay_t	*g_replay_head[REPLAY_SLOT_MAX_N];
+check_memory_def( check_memory_replay_c_g_replay_head )
 static replay_t	*g_replay_cur[REPLAY_SLOT_MAX_N];
+check_memory_def( check_memory_replay_c_g_replay_cur )
 static replay_t	*g_replay_cur_draw;
+check_memory_def( check_memory_replay_c_g_replay_cur_draw )
 
 static bool_t	g_flg_play_replay;
 static long	g_play_replay_turn;
 static long	g_play_replay_count;
 static long	g_play_replay_char;
+check_memory_def( check_memory_replay_c_g_flg_play_replay )
 
 static long	g_play_replay_idx;
 static long	g_play_replay_idx_draw;
+check_memory_def( check_memory_replay_c_g_play_replay_idx )
 
 /***************************************************************
 * ץ쥤
@@ -737,3 +745,27 @@ void	free_replay( replay_t *p )
 {
 	free_mem( p );
 }
+
+/***************************************************************
+* ꡼å
+***************************************************************/
+
+void	check_memory_replay_c( void )
+{
+	check_memory( check_memory_replay_c_g_replay_save_slot,
+			"replay.c: g_replay_save_slot" );
+	check_memory( check_memory_replay_c_g_flg_reg_replay,
+			"replay.c: g_flg_reg_replay" );
+	check_memory( check_memory_replay_c_g_replay_randm_seed,
+			"replay.c: g_replay_randm_seed" );
+	check_memory( check_memory_replay_c_g_replay_head,
+			"replay.c: g_replay_head" );
+	check_memory( check_memory_replay_c_g_replay_cur,
+			"replay.c: g_replay_cur" );
+	check_memory( check_memory_replay_c_g_replay_cur_draw,
+			"replay.c: g_replay_cur_draw" );
+	check_memory( check_memory_replay_c_g_flg_play_replay,
+			"replay.c: g_flg_play_replay" );
+	check_memory( check_memory_replay_c_g_play_replay_idx,
+			"replay.c: g_play_replay_idx" );
+}
