@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: request.c,v 1.111 2009/06/01 05:05:04 bowkenken Exp $
+* $Id: request.c,v 1.113 2009/07/02 22:29:45 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -125,15 +125,20 @@ scroll_kind_t	ls_reward_scroll[] = {
 
 	SCROLL_KIND_NULL,
 };
+check_memory_def( check_memory_request_c_ls_reward_scroll )
 
 /***************************************************************
 * Хѿ
 ***************************************************************/
 
 /* Υǡꥹ */
+check_memory_def( check_memory_request_c_g_request_pre )
 static request_t	g_request[REQUEST_MAX_N];
+check_memory_def( check_memory_request_c_g_request )
+
 /* Υ˥塼 */
 static menu_t	ls_menu_request[1 + REQUEST_MAX_N * 2];
+check_memory_def( check_memory_request_c_ls_menu_request )
 
 /***************************************************************
 * Υơ֥
@@ -247,8 +252,6 @@ request_t	*make_request_rare_goods( request_t *req )
 	if( req == NULL )
 		return NULL;
 
-	req->kind = REQUEST_KIND_RARE_GOODS;
-
 	dun_max_lev = get_request_dun_max_lev_easy();
 	dun_lev = REQUEST_DUN_MIN_LEV_EASY;
 	dun_lev += randm( dun_max_lev - REQUEST_DUN_MIN_LEV_EASY );
@@ -279,10 +282,14 @@ request_t	*make_request_rare_goods( request_t *req )
 
 	req->prize = calc_mnstr_gold( labs( req->dun_max_lev ),
 			REQUEST_RARE_GOODS_GOLD_RATE );
-	req->exp = calc_mnstr_exp( NULL, labs( req->dun_max_lev ) );
+	req->exp = calc_mnstr_exp( req->mnstr_kind,
+			labs( req->dun_max_lev ) );
 	req->exp *= REQUEST_RARE_GOODS_EXP_RATE;
 	req->exp /= _100_PERCENT;
 
+	/**/
+	req->kind = REQUEST_KIND_RARE_GOODS;
+
 	req->idx_fmt = get_ls_n_msg_idx_randm( g_rare_goods_tab );
 	set_request_msg( req );
 	set_request_heading( req );
@@ -305,8 +312,6 @@ request_t	*make_request_tame_mnstr( request_t *req )
 	if( req == NULL )
 		return NULL;
 
-	req->kind = REQUEST_KIND_TAME_MNSTR;
-
 	dun_max_lev = get_request_dun_max_lev_easy();
 	set_request_dun_lev( req,
 			REQUEST_DUN_MIN_LEV_EASY,
@@ -334,10 +339,14 @@ request_t	*make_request_tame_mnstr( request_t *req )
 
 	req->prize = calc_mnstr_gold( labs( req->dun_max_lev ),
 			REQUEST_TAME_MNSTR_GOLD_RATE );
-	req->exp = calc_mnstr_exp( NULL, labs( req->dun_max_lev ) );
+	req->exp = calc_mnstr_exp( MNSTR_KIND_NULL,
+			labs( req->dun_max_lev ) );
 	req->exp *= REQUEST_TAME_MNSTR_EXP_RATE;
 	req->exp /= _100_PERCENT;
 
+	/**/
+	req->kind = REQUEST_KIND_TAME_MNSTR;
+
 	req->idx_fmt = get_ls_n_msg_idx_randm( g_tame_mnstr_tab );
 	set_request_msg( req );
 	set_request_heading( req );
@@ -359,8 +368,6 @@ request_t	*make_request_rescue( request_t *req )
 	if( req == NULL )
 		return NULL;
 
-	req->kind = REQUEST_KIND_RESCUE;
-
 	dun_max_lev = get_request_dun_max_lev_normal();
 	set_request_dun_lev( req,
 			REQUEST_DUN_MIN_LEV_NORMAL,
@@ -384,10 +391,14 @@ request_t	*make_request_rescue( request_t *req )
 
 	req->prize = calc_mnstr_gold( labs( req->dun_max_lev ),
 			REQUEST_RESCUE_GOLD_RATE );
-	req->exp = calc_mnstr_exp( NULL, labs( req->dun_max_lev ) );
+	req->exp = calc_mnstr_exp( MNSTR_KIND_NULL,
+			labs( req->dun_max_lev ) );
 	req->exp *= REQUEST_RESCUE_EXP_RATE;
 	req->exp /= _100_PERCENT;
 
+	/**/
+	req->kind = REQUEST_KIND_RESCUE;
+
 	req->idx_fmt = get_ls_n_msg_idx_randm( g_rescue_tab );
 	set_request_msg( req );
 	set_request_heading( req );
@@ -412,8 +423,6 @@ request_t	*make_request_tour_guide( request_t *req )
 	if( req == NULL )
 		return NULL;
 
-	req->kind = REQUEST_KIND_TOUR_GUIDE;
-
 	dun_max_lev = get_request_dun_max_lev_easy();
 	dun_lev = REQUEST_DUN_MIN_LEV_EASY;
 	dun_lev += randm( dun_max_lev - REQUEST_DUN_MIN_LEV_EASY );
@@ -447,10 +456,14 @@ request_t	*make_request_tour_guide( request_t *req )
 
 	req->prize = calc_mnstr_gold( labs( req->dun_max_lev ),
 			REQUEST_TOUR_GUIDE_GOLD_RATE );
-	req->exp = calc_mnstr_exp( NULL, labs( req->dun_max_lev ) );
+	req->exp = calc_mnstr_exp( req->mnstr_kind,
+			labs( req->dun_max_lev ) );
 	req->exp *= REQUEST_TOUR_GUIDE_EXP_RATE;
 	req->exp /= _100_PERCENT;
 
+	/**/
+	req->kind = REQUEST_KIND_TOUR_GUIDE;
+
 	req->idx_fmt = get_ls_n_msg_idx_randm( g_tour_guide_tab );
 	set_request_msg( req );
 	set_request_heading( req );
@@ -475,8 +488,6 @@ request_t	*make_request_exterminate( request_t *req )
 	if( req == NULL )
 		return NULL;
 
-	req->kind = REQUEST_KIND_EXTERMINATE;
-
 	dun_max_lev = get_request_dun_max_lev_normal();
 	dun_lev = REQUEST_DUN_MIN_LEV_NORMAL;
 	dun_lev += randm( dun_max_lev - REQUEST_DUN_MIN_LEV_NORMAL );
@@ -512,10 +523,14 @@ request_t	*make_request_exterminate( request_t *req )
 
 	req->prize = calc_mnstr_gold( labs( req->dun_max_lev ),
 			REQUEST_EXTERMINATE_GOLD_RATE );
-	req->exp = calc_mnstr_exp( NULL, labs( req->dun_max_lev ) );
+	req->exp = calc_mnstr_exp( req->mnstr_kind,
+			labs( req->dun_max_lev ) );
 	req->exp *= REQUEST_EXTERMINATE_EXP_RATE;
 	req->exp /= _100_PERCENT;
 
+	/**/
+	req->kind = REQUEST_KIND_EXTERMINATE;
+
 	req->idx_fmt = get_ls_n_msg_idx_randm( g_exterminate_tab );
 	set_request_msg( req );
 	set_request_heading( req );
@@ -537,8 +552,6 @@ request_t	*make_request_revenge( request_t *req )
 	if( req == NULL )
 		return NULL;
 
-	req->kind = REQUEST_KIND_REVENGE;
-
 	dun_max_lev = get_request_dun_max_lev_normal();
 	set_request_dun_lev( req,
 			REQUEST_DUN_MIN_LEV_NORMAL,
@@ -567,10 +580,14 @@ request_t	*make_request_revenge( request_t *req )
 
 	req->prize = calc_mnstr_gold( labs( req->dun_max_lev ),
 			REQUEST_REVENGE_GOLD_RATE );
-	req->exp = calc_mnstr_exp( NULL, labs( req->dun_max_lev ) );
+	req->exp = calc_mnstr_exp( req->mnstr_kind,
+			labs( req->dun_max_lev ) );
 	req->exp *= REQUEST_REVENGE_EXP_RATE;
 	req->exp /= _100_PERCENT;
 
+	/**/
+	req->kind = REQUEST_KIND_REVENGE;
+
 	req->idx_fmt = get_ls_n_msg_idx_randm( g_revenge_tab );
 	set_request_msg( req );
 	set_request_heading( req );
@@ -592,8 +609,6 @@ request_t	*make_request_wanted_criminal( request_t *req )
 	if( req == NULL )
 		return NULL;
 
-	req->kind = REQUEST_KIND_WANTED_CRIMINAL;
-
 	dun_max_lev = get_request_dun_max_lev_normal();
 	set_request_dun_lev( req,
 			REQUEST_DUN_MIN_LEV_NORMAL,
@@ -622,10 +637,14 @@ request_t	*make_request_wanted_criminal( request_t *req )
 
 	req->prize = calc_mnstr_gold( labs( req->dun_max_lev ),
 			REQUEST_WANTED_CRIMINAL_GOLD_RATE );
-	req->exp = calc_mnstr_exp( NULL, labs( req->dun_max_lev ) );
+	req->exp = calc_mnstr_exp( req->mnstr_kind,
+			labs( req->dun_max_lev ) );
 	req->exp *= REQUEST_WANTED_CRIMINAL_EXP_RATE;
 	req->exp /= _100_PERCENT;
 
+	/**/
+	req->kind = REQUEST_KIND_WANTED_CRIMINAL;
+
 	req->idx_fmt = get_ls_n_msg_idx_randm( g_wanted_criminal_tab );
 	set_request_msg( req );
 	set_request_heading( req );
@@ -2717,7 +2736,9 @@ char	*set_menu_request(
 
 	n = 0;
 	for( i = 0; i < REQUEST_MAX_N; i++ ){
-		if( g_request[i].kind == REQUEST_KIND_NULL )
+		if( g_request[i].kind <= REQUEST_KIND_NULL )
+			continue;
+		if( g_request[i].kind >= REQUEST_KIND_MAX_N )
 			continue;
 
 		/* СƤʳåפ */
@@ -3156,3 +3177,18 @@ char	*cv_idx_to_client_mate_name( request_t *req )
 	return( MSG( n_msg ) );
 }
 
+/***************************************************************
+* ꡼å
+***************************************************************/
+
+void	check_memory_request_c( void )
+{
+	check_memory( check_memory_request_c_ls_reward_scroll,
+			"request.c: ls_reward_scroll" );
+	check_memory( check_memory_request_c_g_request_pre,
+			"request.c: g_request pre" );
+	check_memory( check_memory_request_c_g_request,
+			"request.c: g_request" );
+	check_memory( check_memory_request_c_ls_menu_request,
+			"request.c: ls_menu_request" );
+}
