@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: spell.c,v 1.190 2009/06/01 13:47:35 bowkenken Exp $
+* $Id: spell.c,v 1.198 2009/06/27 23:34:50 bowkenken Exp $
 ***************************************************************/
 
 #define	SPELL_C
@@ -65,17 +65,25 @@
 /**/
 
 static cast_tab_t	cast_tab[LS_MBR_MAX_N][SPELL_KIND_MAX_N];
+check_memory_def( check_memory_spell_c_cast_tab )
 
 static mbr_t	*g_sel_mbr;
 static spell_tab_t	*g_sel_spell;
+check_memory_def( check_memory_spell_c_g_sel_mbr )
 
 static menu_t	*g_dflt_spell_abl[LS_MBR_MAX_N];
+check_memory_def( check_memory_spell_c_g_dflt_spell_abl )
 static menu_t	*g_dflt_spell[LS_MBR_MAX_N][ABL_KIND_MAX_N];
+check_memory_def( check_memory_spell_c_g_dflt_spell )
 static menu_t	*g_dflt_spell_extent[LS_MBR_MAX_N][ABL_KIND_MAX_N];
+check_memory_def( check_memory_spell_c_g_dflt_spell_extent )
 static abl_kind_t	g_sel_spell_abl;
+check_memory_def( check_memory_spell_c_g_sel_spell_abl )
 
 static long	g_vfx_n;
+check_memory_def( check_memory_spell_c_g_vfx_n )
 static pos_t	g_vfx_bgn[VFX_ARW_MAX_N], g_vfx_end[VFX_ARW_MAX_N];
+check_memory_def( check_memory_spell_c_g_vfx_bgn )
 
 /**/
 
@@ -191,28 +199,34 @@ void	init_spell_debug( void )
 
 	m = LS_MBR_N_CECILE;
 	for( k = SPELL_KIND_PRI_MIN_N + 1; k < SPELL_KIND_PRI_MAX_N; k++ ){
+#if	0
 		if( k == SPELL_KIND_CURE_PARALYZE )
 			continue;
 		if( k == SPELL_KIND_CURE_BLINDNESS )
 			continue;
+#endif
 
 		cast_tab[m][k].flg_cast = TRUE;
 	}
 
 	m = LS_MBR_N_HALLE;
 	for( k = SPELL_KIND_BAR_MIN_N + 1; k < SPELL_KIND_BAR_MAX_N; k++ ){
+#if	0
 		if( k == SPELL_KIND_SONG_DULLNESS )
 			continue;
+#endif
 
 		cast_tab[m][k].flg_cast = TRUE;
 	}
 
 	m = LS_MBR_N_BEAUT;
 	for( k = SPELL_KIND_NULL + 1; k < SPELL_KIND_MAX_N; k++ ){
+#if	0
 		if( k == SPELL_KIND_CREATE_FOOD )
 			continue;
 		if( k == SPELL_KIND_CREATE_UNDEAD )
 			continue;
+#endif
 
 		cast_tab[m][k].flg_cast = TRUE;
 	}
@@ -271,38 +285,68 @@ char	*cb_menu_sel_spell( menu_t **pp, menu_t **dflt )
 {
 	mbr_t	*pre_sel_mbr;
 	pos_t	*crsr;
+	bool_t	flg_sel_mbr;
+	char	*str_goto;
+
+	pre_sel_mbr = static_cb_menu_sel_spell__pre_sel_mbr;
+
+	set_menu_dflt_main( *pp );
+
+	crsr = get_crsr();
+	g_sel_mbr = get_mbr( crsr->x, crsr->y );
+	if( g_sel_mbr == NULL )
+		flg_sel_mbr = TRUE;
+	else
+		flg_sel_mbr = FALSE;
+
+	do {
+		if( flg_sel_mbr ){
+			char	*str;
+
+			g_sel_mbr = pre_sel_mbr;
+
+			str = exec_menu_sel_mbr( &g_sel_mbr, NULL,
+					FALSE, FALSE );
+			if( str != NULL )
+				return STR_MENU_ERR;
+		}
+		if( g_sel_mbr == NULL )
+			return STR_MENU_ERR;
+
+		pre_sel_mbr = g_sel_mbr;
+		static_cb_menu_sel_spell__pre_sel_mbr = pre_sel_mbr;
+
+		str_goto = menu_sel_spell( g_sel_mbr );
+		if( str_goto == NULL )
+			return NULL;
+		if( strcmp( str_goto, STR_MENU_CANCEL ) == 0 )
+			continue;
+		if( strcmp( str_goto, STR_MENU_ERR ) == 0 )
+			return str_goto;
+	} while( flg_sel_mbr );
+
+	return NULL;
+}
+
+/**/
+
+char	*menu_sel_spell( mbr_t *mbr )
+{
+	menu_t *dflt;
 	menu_t	*ls;
 	unsigned char	key;
 	bool_t	flg;
 	bool_t	flg_learn;
 	long	i;
 
-	pre_sel_mbr = static_cb_menu_sel_spell__pre_sel_mbr;
-
-	crsr = get_crsr();
-	g_sel_mbr = get_mbr( crsr->x, crsr->y );
-	if( g_sel_mbr == NULL ){
-		char	*str;
-
-		g_sel_mbr = pre_sel_mbr;
-
-		str = exec_menu_sel_mbr( &g_sel_mbr, NULL, FALSE, FALSE );
-		if( str != NULL )
-			return STR_MENU_ERR;
-	}
-	if( g_sel_mbr == NULL )
+	if( mbr == NULL )
 		return STR_MENU_ERR;
 
-	pre_sel_mbr = g_sel_mbr;
-	static_cb_menu_sel_spell__pre_sel_mbr = pre_sel_mbr;
-
-	if( !chk_can_chr_cast_stat( g_sel_mbr ) ){
-		print_msg( FLG_NULL, MSG_ERR_SPELL, g_sel_mbr->name );
+	if( !chk_can_chr_cast_stat( mbr ) ){
+		print_msg( FLG_NULL, MSG_ERR_SPELL, mbr->name );
 		return STR_MENU_CANCEL;
 	}
 
-	set_menu_dflt_main( *pp );
-
 	ls = ls_menu_spell;
 	clr_flg_menu( ls, NULL, FLG_MENU_ALL );
 
@@ -333,7 +377,7 @@ char	*cb_menu_sel_spell( menu_t **pp, menu_t **dflt )
 		key++;
 
 		kind = (spell_kind_t)(long)(ls[i].arg);
-		if( chk_can_chr_cast_lev( g_sel_mbr, kind ) ){
+		if( chk_can_chr_cast_lev( mbr, kind ) ){
 			ls[i].flg &= ~FLG_MENU_HIDDEN;
 			flg_learn = TRUE;
 		} else {
@@ -343,71 +387,69 @@ char	*cb_menu_sel_spell( menu_t **pp, menu_t **dflt )
 
 	flg = FALSE;
 
-	if( get_lev( g_sel_mbr, ABL_KIND_MAG ) > 0 ){
+	if( get_lev( mbr, ABL_KIND_MAG ) > 0 ){
 		clr_flg_menu( ls, "MAG", FLG_MENU_HIDDEN );
 		flg = TRUE;
 	} else {
 		set_flg_menu( ls, "MAG", FLG_MENU_HIDDEN );
 	}
 
-	if( get_lev( g_sel_mbr, ABL_KIND_SOR ) > 0 ){
+	if( get_lev( mbr, ABL_KIND_SOR ) > 0 ){
 		clr_flg_menu( ls, "SOR", FLG_MENU_HIDDEN );
 		flg = TRUE;
 	} else {
 		set_flg_menu( ls, "SOR", FLG_MENU_HIDDEN );
 	}
 
-	if( get_lev( g_sel_mbr, ABL_KIND_ENC ) > 0 ){
+	if( get_lev( mbr, ABL_KIND_ENC ) > 0 ){
 		clr_flg_menu( ls, "ENC", FLG_MENU_HIDDEN );
 		flg = TRUE;
 	} else {
 		set_flg_menu( ls, "ENC", FLG_MENU_HIDDEN );
 	}
 
-	if( get_lev( g_sel_mbr, ABL_KIND_SUM ) > 0 ){
+	if( get_lev( mbr, ABL_KIND_SUM ) > 0 ){
 		clr_flg_menu( ls, "SUM", FLG_MENU_HIDDEN );
 		flg = TRUE;
 	} else {
 		set_flg_menu( ls, "SUM", FLG_MENU_HIDDEN );
 	}
 
-	if( get_lev( g_sel_mbr, ABL_KIND_PRI ) > 0 ){
+	if( get_lev( mbr, ABL_KIND_PRI ) > 0 ){
 		clr_flg_menu( ls, "PRI", FLG_MENU_HIDDEN );
 		flg = TRUE;
 	} else {
 		set_flg_menu( ls, "PRI", FLG_MENU_HIDDEN );
 	}
 
-	if( get_lev( g_sel_mbr, ABL_KIND_SHA ) > 0 ){
+	if( get_lev( mbr, ABL_KIND_SHA ) > 0 ){
 		clr_flg_menu( ls, "SHA", FLG_MENU_HIDDEN );
 		flg = TRUE;
 	} else {
 		set_flg_menu( ls, "SHA", FLG_MENU_HIDDEN );
 	}
 
-	if( get_lev( g_sel_mbr, ABL_KIND_BAR ) > 0 ){
+	if( get_lev( mbr, ABL_KIND_BAR ) > 0 ){
 		clr_flg_menu( ls, "BAR", FLG_MENU_HIDDEN );
 		flg = TRUE;
 	} else {
 		set_flg_menu( ls, "BAR", FLG_MENU_HIDDEN );
 	}
 
-	if( get_lev( g_sel_mbr, ABL_KIND_NIN ) > 0 ){
+	if( get_lev( mbr, ABL_KIND_NIN ) > 0 ){
 		clr_flg_menu( ls, "NIN", FLG_MENU_HIDDEN );
 		flg = TRUE;
 	} else {
 		set_flg_menu( ls, "NIN", FLG_MENU_HIDDEN );
 	}
 
-	*pp = ls;
-	*dflt = g_dflt_spell_abl[g_sel_mbr->ls_mbr_n];
-
 	if( !flg ){
-		print_msg( FLG_NULL, MSG_ERR_SPELL, g_sel_mbr->name );
+		print_msg( FLG_NULL, MSG_ERR_SPELL, mbr->name );
 		return STR_MENU_CANCEL;
 	}
 
-	return NULL;
+	dflt = g_dflt_spell_abl[mbr->ls_mbr_n];
+	return exec_menu( ls, dflt, NULL );
 }
 
 /**/
@@ -552,7 +594,8 @@ char	*cb_menu_spell( menu_t **pp, menu_t **dflt )
 
 char	*cb_menu_spell_extent( menu_t **pp, menu_t **dflt )
 {
-	char	*str_goto;
+	extent_kind_t	ex;
+	bool_t	flg_trgt;
 
 	if( g_sel_mbr == NULL )
 		return STR_MENU_ERR;
@@ -561,7 +604,26 @@ char	*cb_menu_spell_extent( menu_t **pp, menu_t **dflt )
 
 	g_dflt_spell_extent[g_sel_mbr->ls_mbr_n][g_sel_spell_abl] = *pp;
 
-	if( g_sel_spell->flg_trgt ){
+	ex = (extent_kind_t)(long)((*pp)->arg);
+
+	flg_trgt = FALSE;
+	if( g_sel_spell->flg_trgt )
+		flg_trgt = TRUE;
+	do {
+		if( g_sel_spell->kind < SPELL_KIND_BAR_MIN_N )
+			break;
+		if( g_sel_spell->kind > SPELL_KIND_BAR_MAX_N )
+			break;
+		if( ex != EXTENT_KIND_NORMAL )
+			break;
+
+		flg_trgt = FALSE;
+		break;
+	} while( 0 );
+
+	if( flg_trgt ){
+		char	*str_goto;
+
 		str_goto = menu_spell_trgt( g_sel_mbr );
 		if( str_goto != NULL )
 			return str_goto;
@@ -569,9 +631,7 @@ char	*cb_menu_spell_extent( menu_t **pp, menu_t **dflt )
 
 	/*  */
 
-	set_chr_act( g_sel_mbr, ACT_KIND_SPELL,
-			g_sel_spell, NULL,
-			(extent_kind_t)(long)((*pp)->arg), 0 );
+	set_chr_act( g_sel_mbr, ACT_KIND_SPELL, g_sel_spell, NULL, ex, 0 );
 
 	return NULL;
 }
@@ -761,11 +821,13 @@ void	chr_cast_spell( chr_t *chr, spell_tab_t *tab, const char *fmt )
 	}
 
 	if( chr->abl.hp.n < hp ){
+		clr_chr_trgt_act( chr, TRUE );
 		print_msg_mbr( chr, FLG_NULL, MSG_ERR_HP_SHORT, chr->name,
 				hp - chr->abl.hp.n );
 		return;
 	}
 	if( chr->abl.mp.n < mp ){
+		clr_chr_trgt_act( chr, TRUE );
 		print_msg_mbr( chr, FLG_NULL, MSG_ERR_MP_SHORT, chr->name,
 				mp - chr->abl.mp.n );
 		return;
@@ -783,6 +845,7 @@ void	chr_cast_spell( chr_t *chr, spell_tab_t *tab, const char *fmt )
 
 		d = chr->resi[kind].n - ((resi / _100_PERCENT) + 1);
 		if( d <= 0 ){
+			clr_chr_trgt_act( chr, TRUE );
 			print_msg_mbr( chr, FLG_NULL,
 					MSG_ERR_RESI_SHORT,
 					chr->name, -d + 1 );
@@ -845,6 +908,10 @@ void	chr_cast_spell( chr_t *chr, spell_tab_t *tab, const char *fmt )
 	case EXTENT_KIND_MAX_N:
 		break;
 	case EXTENT_KIND_NORMAL:
+		if( (SPELL_KIND_BAR_MIN_N <= tab->kind)
+				&& (tab->kind <= SPELL_KIND_BAR_MAX_N) ){
+			break;
+		}
 		chr_cast_spell_normal( chr, FALSE, tab, _100_PERCENT );
 		break;
 	case EXTENT_KIND_SPREAD:
@@ -1000,6 +1067,7 @@ void	chr_cast_spell_blast(
 	long	xx, yy;
 	bool_t	flg_actual;
 	chr_kind_t	kind;
+	chr_t	*trgt_chr;
 
 	if( chr == NULL )
 		return;
@@ -1035,6 +1103,7 @@ void	chr_cast_spell_blast(
 
 	flg_actual = chk_flg( get_flg_party(), FLG_PARTY_ACTUAL_FIGHTING );
 
+	clr_all_chr_flg_blast();
 	bgn_sync_vfx_num();
 
 	for( ny = 0; ny < blast->yl; ny++ ){
@@ -1045,11 +1114,13 @@ void	chr_cast_spell_blast(
 			xx = x + nx - (blast->xr / 2);
 			yy = y + ny - blast->yr;
 
+			trgt_chr = NULL;
 			p = NULL;
 
 			switch( trgt_kind ){
 			case TRGT_KIND_MBR:
-				p = get_mbr( xx, yy );
+				trgt_chr = get_mbr( xx, yy );
+				p = trgt_chr;
 				break;
 			case TRGT_KIND_NULL:
 			case TRGT_KIND_MNSTR:
@@ -1058,7 +1129,8 @@ void	chr_cast_spell_blast(
 			case TRGT_KIND_POS:
 				trgt_kind = TRGT_KIND_MNSTR;
 
-				p = get_mnstr( xx, yy );
+				trgt_chr = get_mnstr( xx, yy );
+				p = trgt_chr;
 				if( p == NULL )
 					break;
 				if( p == chr )
@@ -1092,6 +1164,17 @@ void	chr_cast_spell_blast(
 			if( p == NULL )
 				continue;
 
+			/* äƤ̵ */
+
+			if( trgt_chr != NULL ){
+				if( chk_flg( trgt_chr->work.flg,
+						FLG_WORK_BLAST_END ) ){
+					continue;
+				}
+
+				trgt_chr->work.flg |= FLG_WORK_BLAST_END;
+			}
+
 			draw_map( xx, yy, 1, 1 );
 
 			chr_cast_spell_sub( chr, flg_item, tab, rate,
@@ -1100,6 +1183,7 @@ void	chr_cast_spell_blast(
 	}
 
 	end_sync_vfx_num();
+	clr_all_chr_flg_blast();
 
 	draw_blast( kind, x, y, blast, blast_str );
 	if( clip_draw_pos( x, y ) )
@@ -1611,6 +1695,7 @@ void	chr_cast_spell_sub(
 
 	if( flg_chr ){
 		if( d_p->gold < tab->gold ){
+			clr_chr_trgt_act( chr, TRUE );
 			print_msg_mbr( d_p, FLG_NULL, MSG_ERR_GOLD_SHORT,
 					d_p->name, tab->gold - d_p->gold );
 
@@ -1704,7 +1789,7 @@ void	chr_cast_spell_sub(
 		fx_store_light( chr );
 		break;
 	case SPELL_KIND_TELEPORT_PARTY:
-		fx_teleport_party();
+		fx_teleport_party_charge();
 		break;
 	case SPELL_KIND_TELEPORT:
 		fx_teleport( trgt_kind, p );
@@ -2074,7 +2159,7 @@ void	chr_cast_spell_sub(
 		fx_dispel_undead( chr, trgt_kind, (chr_t *)p, rate );
 		break;
 	case SPELL_KIND_ESCAPE:
-		fx_teleport_party();
+		fx_teleport_party_charge();
 		break;
 	case SPELL_KIND_SANCTUARY:
 		fx_sanctuary( chr, ABL_KIND_PRI );
@@ -3581,5 +3666,28 @@ gold_t	get_price_spell( spell_kind_t kind )
 	return price;
 }
 
-/**/
+/***************************************************************
+* ꡼å
+***************************************************************/
 
+void	check_memory_spell_c( void )
+{
+	check_memory( check_memory_spell_c_cast_tab,
+			"spell.c: cast_tab" );
+	check_memory( check_memory_spell_c_g_sel_mbr,
+			"spell.c: g_sel_mbr" );
+	check_memory( check_memory_spell_c_g_dflt_spell_abl,
+			"spell.c: g_dflt_spell_abl" );
+	check_memory( check_memory_spell_c_g_dflt_spell,
+			"spell.c: g_dflt_spell" );
+	check_memory( check_memory_spell_c_g_dflt_spell_extent,
+			"spell.c: g_dflt_spell_extent" );
+	check_memory( check_memory_spell_c_g_sel_spell_abl,
+			"spell.c: g_sel_spell_abl" );
+	check_memory( check_memory_spell_c_g_vfx_n,
+			"spell.c: g_vfx_n" );
+	check_memory( check_memory_spell_c_g_vfx_bgn,
+			"spell.c: g_vfx_bgn" );
+}
+
+/**/
