@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: town.c,v 1.153 2009/06/01 05:05:04 bowkenken Exp $
+* $Id: town.c,v 1.157 2009/07/11 03:42:14 bowkenken Exp $
 ***************************************************************/
 
 #define	TOWN_C
@@ -200,6 +200,7 @@
 #define	DISCOUNT_QUEUE_R	4
 
 discount_queue_t	g_discount_queue;
+check_memory_def( check_memory_town_c_g_discount_queue )
 
 /***************************************************************
 * ¾
@@ -227,9 +228,13 @@ discount_queue_t	g_discount_queue;
 ***************************************************************/
 
 static town_ptn_t	town_ptn, town_ptn_trans;
+check_memory_def( check_memory_town_c_town_ptn )
 
 static long	g_morning_glow_n, g_evening_glow_n;
+check_memory_def( check_memory_town_c_g_morning_glow_n )
+
 static bool_t	g_flg_night;
+check_memory_def( check_memory_town_c_g_flg_night )
 
 /***************************************************************
 * 
@@ -1474,7 +1479,7 @@ bool_t	enter_shop( void )
 	pty = get_party();
 	pet = get_party_pet();
 
-	set_flg_load_game_data( FALSE );
+	set_flg_exit_shop( TRUE );
 
 	if( pty->act.kind != ACT_KIND_SHOP )
 		return FALSE;
@@ -1529,7 +1534,7 @@ bool_t	enter_shop( void )
 			print_msg( FLG_MSG_ERR, MSG_S,
 					MSG_ERR_NOT_EXIST_ALL_MBR );
 		} else {
-			if( !get_flg_load_game_data() )
+			if( get_flg_exit_shop() )
 				party_exit_shop( dr_n );
 			break;
 		}
@@ -1545,6 +1550,7 @@ bool_t	enter_shop( void )
 
 void	party_exit_shop( long dr_n )
 {
+	long	seed;
 	dun_t	*dun;
 	party_t	*pty;
 	long	x, y;
@@ -1552,6 +1558,8 @@ void	party_exit_shop( long dr_n )
 	bool_t	flg_force;
 	long	i, j;
 
+	seed = get_randm_seed();
+
 	dun = get_dun();
 	pty = get_party();
 
@@ -1632,6 +1640,8 @@ void	party_exit_shop( long dr_n )
 		add_turn( SHOP_ADD_TURN_N );
 
 	change_scene( SCENE_N_TOWN );
+
+	srandm( seed );
 }
 
 /***************************************************************
@@ -1863,11 +1873,16 @@ void	party_enter_bar( void )
 void	party_exit_bar( void )
 {
 	door_t	*dr;
+	long	seed;
+
+	seed = get_randm_seed();
 
 	dr = get_shop_door( SHOP_N_BAR );
 	if( dr == NULL )
 		return;
 
+	srandm( seed );
+
 	party_exit_shop( dr->n );
 }
 
@@ -2139,6 +2154,8 @@ void	stay_inn( bool_t flg_short_stay, bool_t flg_mews )
 
 void	take_bath( chr_t *chr )
 {
+	long	j;
+
 	if( chr == NULL )
 		return;
 
@@ -2161,6 +2178,14 @@ void	take_bath( chr_t *chr )
 				MSG_WORDS_CHR_IS_MOLESTED_FAMALE,
 				MSG_WORDS_CHR_IS_MOLESTED_MALE );
 	}
+
+	/* ͤꥻå */
+
+	for( j = 0; j < RESI_KIND_MAX_N; j++ ){
+		reset_mbr_resi( chr );
+		chr->resi[j].n = get_resi_max(
+				chr, (resi_kind_t)j );
+	}
 }
 
 /***************************************************************
@@ -3779,3 +3804,19 @@ bool_t	save_town( void )
 
 	return TRUE;
 }
+
+/***************************************************************
+* ꡼å
+***************************************************************/
+
+void	check_memory_town_c( void )
+{
+	check_memory( check_memory_town_c_g_discount_queue,
+			"town.c: g_discount_queue" );
+	check_memory( check_memory_town_c_town_ptn,
+			"town.c: town_ptn" );
+	check_memory( check_memory_town_c_g_morning_glow_n,
+			"town.c: g_morning_glow_n" );
+	check_memory( check_memory_town_c_g_flg_night,
+			"town.c: g_flg_night" );
+}
